(**************************************************************************)
(*                Lablgtk                                                 *)
(*                                                                        *)
(*    This program is free software; you can redistribute it              *)
(*    and/or modify it under the terms of the GNU Library General         *)
(*    Public License as published by the Free Software Foundation         *)
(*    version 2, with the exception described in file COPYING which       *)
(*    comes with the library.                                             *)
(*                                                                        *)
(*    This program is distributed in the hope that it will be useful,     *)
(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
(*    GNU Library General Public License for more details.                *)
(*                                                                        *)
(*    You should have received a copy of the GNU Library General          *)
(*    Public License along with this program; if not, write to the        *)
(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
(*    Boston, MA 02111-1307  USA                                          *)
(*                                                                        *)
(*                                                                        *)
(**************************************************************************)

(* $Id$ *)

open Gdk
let _VoidSymbol : keysym = 0xffffff
let _BackSpace : keysym = 0xff08
let _Tab : keysym = 0xff09
let _Linefeed : keysym = 0xff0a
let _Clear : keysym = 0xff0b
let _Return : keysym = 0xff0d
let _Pause : keysym = 0xff13
let _Scroll_Lock : keysym = 0xff14
let _Sys_Req : keysym = 0xff15
let _Escape : keysym = 0xff1b
let _Delete : keysym = 0xffff
let _Multi_key : keysym = 0xff20
let _Codeinput : keysym = 0xff37
let _SingleCandidate : keysym = 0xff3c
let _MultipleCandidate : keysym = 0xff3d
let _PreviousCandidate : keysym = 0xff3e
let _Kanji : keysym = 0xff21
let _Muhenkan : keysym = 0xff22
let _Henkan_Mode : keysym = 0xff23
let _Henkan : keysym = 0xff23
let _Romaji : keysym = 0xff24
let _Hiragana : keysym = 0xff25
let _Katakana : keysym = 0xff26
let _Hiragana_Katakana : keysym = 0xff27
let _Zenkaku : keysym = 0xff28
let _Hankaku : keysym = 0xff29
let _Zenkaku_Hankaku : keysym = 0xff2a
let _Touroku : keysym = 0xff2b
let _Massyo : keysym = 0xff2c
let _Kana_Lock : keysym = 0xff2d
let _Kana_Shift : keysym = 0xff2e
let _Eisu_Shift : keysym = 0xff2f
let _Eisu_toggle : keysym = 0xff30
let _Kanji_Bangou : keysym = 0xff37
let _Zen_Koho : keysym = 0xff3d
let _Mae_Koho : keysym = 0xff3e
let _Home : keysym = 0xff50
let _Left : keysym = 0xff51
let _Up : keysym = 0xff52
let _Right : keysym = 0xff53
let _Down : keysym = 0xff54
let _Prior : keysym = 0xff55
let _Page_Up : keysym = 0xff55
let _Next : keysym = 0xff56
let _Page_Down : keysym = 0xff56
let _End : keysym = 0xff57
let _Begin : keysym = 0xff58
let _Select : keysym = 0xff60
let _Print : keysym = 0xff61
let _Execute : keysym = 0xff62
let _Insert : keysym = 0xff63
let _Undo : keysym = 0xff65
let _Redo : keysym = 0xff66
let _Menu : keysym = 0xff67
let _Find : keysym = 0xff68
let _Cancel : keysym = 0xff69
let _Help : keysym = 0xff6a
let _Break : keysym = 0xff6b
let _Mode_switch : keysym = 0xff7e
let _script_switch : keysym = 0xff7e
let _Num_Lock : keysym = 0xff7f
let _KP_Space : keysym = 0xff80
let _KP_Tab : keysym = 0xff89
let _KP_Enter : keysym = 0xff8d
let _KP_F1 : keysym = 0xff91
let _KP_F2 : keysym = 0xff92
let _KP_F3 : keysym = 0xff93
let _KP_F4 : keysym = 0xff94
let _KP_Home : keysym = 0xff95
let _KP_Left : keysym = 0xff96
let _KP_Up : keysym = 0xff97
let _KP_Right : keysym = 0xff98
let _KP_Down : keysym = 0xff99
let _KP_Prior : keysym = 0xff9a
let _KP_Page_Up : keysym = 0xff9a
let _KP_Next : keysym = 0xff9b
let _KP_Page_Down : keysym = 0xff9b
let _KP_End : keysym = 0xff9c
let _KP_Begin : keysym = 0xff9d
let _KP_Insert : keysym = 0xff9e
let _KP_Delete : keysym = 0xff9f
let _KP_Equal : keysym = 0xffbd
let _KP_Multiply : keysym = 0xffaa
let _KP_Add : keysym = 0xffab
let _KP_Separator : keysym = 0xffac
let _KP_Subtract : keysym = 0xffad
let _KP_Decimal : keysym = 0xffae
let _KP_Divide : keysym = 0xffaf
let _KP_0 : keysym = 0xffb0
let _KP_1 : keysym = 0xffb1
let _KP_2 : keysym = 0xffb2
let _KP_3 : keysym = 0xffb3
let _KP_4 : keysym = 0xffb4
let _KP_5 : keysym = 0xffb5
let _KP_6 : keysym = 0xffb6
let _KP_7 : keysym = 0xffb7
let _KP_8 : keysym = 0xffb8
let _KP_9 : keysym = 0xffb9
let _F1 : keysym = 0xffbe
let _F2 : keysym = 0xffbf
let _F3 : keysym = 0xffc0
let _F4 : keysym = 0xffc1
let _F5 : keysym = 0xffc2
let _F6 : keysym = 0xffc3
let _F7 : keysym = 0xffc4
let _F8 : keysym = 0xffc5
let _F9 : keysym = 0xffc6
let _F10 : keysym = 0xffc7
let _F11 : keysym = 0xffc8
let _L1 : keysym = 0xffc8
let _F12 : keysym = 0xffc9
let _L2 : keysym = 0xffc9
let _F13 : keysym = 0xffca
let _L3 : keysym = 0xffca
let _F14 : keysym = 0xffcb
let _L4 : keysym = 0xffcb
let _F15 : keysym = 0xffcc
let _L5 : keysym = 0xffcc
let _F16 : keysym = 0xffcd
let _L6 : keysym = 0xffcd
let _F17 : keysym = 0xffce
let _L7 : keysym = 0xffce
let _F18 : keysym = 0xffcf
let _L8 : keysym = 0xffcf
let _F19 : keysym = 0xffd0
let _L9 : keysym = 0xffd0
let _F20 : keysym = 0xffd1
let _L10 : keysym = 0xffd1
let _F21 : keysym = 0xffd2
let _R1 : keysym = 0xffd2
let _F22 : keysym = 0xffd3
let _R2 : keysym = 0xffd3
let _F23 : keysym = 0xffd4
let _R3 : keysym = 0xffd4
let _F24 : keysym = 0xffd5
let _R4 : keysym = 0xffd5
let _F25 : keysym = 0xffd6
let _R5 : keysym = 0xffd6
let _F26 : keysym = 0xffd7
let _R6 : keysym = 0xffd7
let _F27 : keysym = 0xffd8
let _R7 : keysym = 0xffd8
let _F28 : keysym = 0xffd9
let _R8 : keysym = 0xffd9
let _F29 : keysym = 0xffda
let _R9 : keysym = 0xffda
let _F30 : keysym = 0xffdb
let _R10 : keysym = 0xffdb
let _F31 : keysym = 0xffdc
let _R11 : keysym = 0xffdc
let _F32 : keysym = 0xffdd
let _R12 : keysym = 0xffdd
let _F33 : keysym = 0xffde
let _R13 : keysym = 0xffde
let _F34 : keysym = 0xffdf
let _R14 : keysym = 0xffdf
let _F35 : keysym = 0xffe0
let _R15 : keysym = 0xffe0
let _Shift_L : keysym = 0xffe1
let _Shift_R : keysym = 0xffe2
let _Control_L : keysym = 0xffe3
let _Control_R : keysym = 0xffe4
let _Caps_Lock : keysym = 0xffe5
let _Shift_Lock : keysym = 0xffe6
let _Meta_L : keysym = 0xffe7
let _Meta_R : keysym = 0xffe8
let _Alt_L : keysym = 0xffe9
let _Alt_R : keysym = 0xffea
let _Super_L : keysym = 0xffeb
let _Super_R : keysym = 0xffec
let _Hyper_L : keysym = 0xffed
let _Hyper_R : keysym = 0xffee
let _ISO_Lock : keysym = 0xfe01
let _ISO_Level2_Latch : keysym = 0xfe02
let _ISO_Level3_Shift : keysym = 0xfe03
let _ISO_Level3_Latch : keysym = 0xfe04
let _ISO_Level3_Lock : keysym = 0xfe05
let _ISO_Level5_Shift : keysym = 0xfe11
let _ISO_Level5_Latch : keysym = 0xfe12
let _ISO_Level5_Lock : keysym = 0xfe13
let _ISO_Group_Shift : keysym = 0xff7e
let _ISO_Group_Latch : keysym = 0xfe06
let _ISO_Group_Lock : keysym = 0xfe07
let _ISO_Next_Group : keysym = 0xfe08
let _ISO_Next_Group_Lock : keysym = 0xfe09
let _ISO_Prev_Group : keysym = 0xfe0a
let _ISO_Prev_Group_Lock : keysym = 0xfe0b
let _ISO_First_Group : keysym = 0xfe0c
let _ISO_First_Group_Lock : keysym = 0xfe0d
let _ISO_Last_Group : keysym = 0xfe0e
let _ISO_Last_Group_Lock : keysym = 0xfe0f
let _ISO_Left_Tab : keysym = 0xfe20
let _ISO_Move_Line_Up : keysym = 0xfe21
let _ISO_Move_Line_Down : keysym = 0xfe22
let _ISO_Partial_Line_Up : keysym = 0xfe23
let _ISO_Partial_Line_Down : keysym = 0xfe24
let _ISO_Partial_Space_Left : keysym = 0xfe25
let _ISO_Partial_Space_Right : keysym = 0xfe26
let _ISO_Set_Margin_Left : keysym = 0xfe27
let _ISO_Set_Margin_Right : keysym = 0xfe28
let _ISO_Release_Margin_Left : keysym = 0xfe29
let _ISO_Release_Margin_Right : keysym = 0xfe2a
let _ISO_Release_Both_Margins : keysym = 0xfe2b
let _ISO_Fast_Cursor_Left : keysym = 0xfe2c
let _ISO_Fast_Cursor_Right : keysym = 0xfe2d
let _ISO_Fast_Cursor_Up : keysym = 0xfe2e
let _ISO_Fast_Cursor_Down : keysym = 0xfe2f
let _ISO_Continuous_Underline : keysym = 0xfe30
let _ISO_Discontinuous_Underline : keysym = 0xfe31
let _ISO_Emphasize : keysym = 0xfe32
let _ISO_Center_Object : keysym = 0xfe33
let _ISO_Enter : keysym = 0xfe34
let _dead_grave : keysym = 0xfe50
let _dead_acute : keysym = 0xfe51
let _dead_circumflex : keysym = 0xfe52
let _dead_tilde : keysym = 0xfe53
let _dead_perispomeni : keysym = 0xfe53
let _dead_macron : keysym = 0xfe54
let _dead_breve : keysym = 0xfe55
let _dead_abovedot : keysym = 0xfe56
let _dead_diaeresis : keysym = 0xfe57
let _dead_abovering : keysym = 0xfe58
let _dead_doubleacute : keysym = 0xfe59
let _dead_caron : keysym = 0xfe5a
let _dead_cedilla : keysym = 0xfe5b
let _dead_ogonek : keysym = 0xfe5c
let _dead_iota : keysym = 0xfe5d
let _dead_voiced_sound : keysym = 0xfe5e
let _dead_semivoiced_sound : keysym = 0xfe5f
let _dead_belowdot : keysym = 0xfe60
let _dead_hook : keysym = 0xfe61
let _dead_horn : keysym = 0xfe62
let _dead_stroke : keysym = 0xfe63
let _dead_abovecomma : keysym = 0xfe64
let _dead_psili : keysym = 0xfe64
let _dead_abovereversedcomma : keysym = 0xfe65
let _dead_dasia : keysym = 0xfe65
let _dead_doublegrave : keysym = 0xfe66
let _dead_belowring : keysym = 0xfe67
let _dead_belowmacron : keysym = 0xfe68
let _dead_belowcircumflex : keysym = 0xfe69
let _dead_belowtilde : keysym = 0xfe6a
let _dead_belowbreve : keysym = 0xfe6b
let _dead_belowdiaeresis : keysym = 0xfe6c
let _dead_invertedbreve : keysym = 0xfe6d
let _dead_belowcomma : keysym = 0xfe6e
let _dead_currency : keysym = 0xfe6f
let _dead_a : keysym = 0xfe80
let _dead_A : keysym = 0xfe81
let _dead_e : keysym = 0xfe82
let _dead_E : keysym = 0xfe83
let _dead_i : keysym = 0xfe84
let _dead_I : keysym = 0xfe85
let _dead_o : keysym = 0xfe86
let _dead_O : keysym = 0xfe87
let _dead_u : keysym = 0xfe88
let _dead_U : keysym = 0xfe89
let _dead_small_schwa : keysym = 0xfe8a
let _dead_capital_schwa : keysym = 0xfe8b
let _dead_greek : keysym = 0xfe8c
let _First_Virtual_Screen : keysym = 0xfed0
let _Prev_Virtual_Screen : keysym = 0xfed1
let _Next_Virtual_Screen : keysym = 0xfed2
let _Last_Virtual_Screen : keysym = 0xfed4
let _Terminate_Server : keysym = 0xfed5
let _AccessX_Enable : keysym = 0xfe70
let _AccessX_Feedback_Enable : keysym = 0xfe71
let _RepeatKeys_Enable : keysym = 0xfe72
let _SlowKeys_Enable : keysym = 0xfe73
let _BounceKeys_Enable : keysym = 0xfe74
let _StickyKeys_Enable : keysym = 0xfe75
let _MouseKeys_Enable : keysym = 0xfe76
let _MouseKeys_Accel_Enable : keysym = 0xfe77
let _Overlay1_Enable : keysym = 0xfe78
let _Overlay2_Enable : keysym = 0xfe79
let _AudibleBell_Enable : keysym = 0xfe7a
let _Pointer_Left : keysym = 0xfee0
let _Pointer_Right : keysym = 0xfee1
let _Pointer_Up : keysym = 0xfee2
let _Pointer_Down : keysym = 0xfee3
let _Pointer_UpLeft : keysym = 0xfee4
let _Pointer_UpRight : keysym = 0xfee5
let _Pointer_DownLeft : keysym = 0xfee6
let _Pointer_DownRight : keysym = 0xfee7
let _Pointer_Button_Dflt : keysym = 0xfee8
let _Pointer_Button1 : keysym = 0xfee9
let _Pointer_Button2 : keysym = 0xfeea
let _Pointer_Button3 : keysym = 0xfeeb
let _Pointer_Button4 : keysym = 0xfeec
let _Pointer_Button5 : keysym = 0xfeed
let _Pointer_DblClick_Dflt : keysym = 0xfeee
let _Pointer_DblClick1 : keysym = 0xfeef
let _Pointer_DblClick2 : keysym = 0xfef0
let _Pointer_DblClick3 : keysym = 0xfef1
let _Pointer_DblClick4 : keysym = 0xfef2
let _Pointer_DblClick5 : keysym = 0xfef3
let _Pointer_Drag_Dflt : keysym = 0xfef4
let _Pointer_Drag1 : keysym = 0xfef5
let _Pointer_Drag2 : keysym = 0xfef6
let _Pointer_Drag3 : keysym = 0xfef7
let _Pointer_Drag4 : keysym = 0xfef8
let _Pointer_Drag5 : keysym = 0xfefd
let _Pointer_EnableKeys : keysym = 0xfef9
let _Pointer_Accelerate : keysym = 0xfefa
let _Pointer_DfltBtnNext : keysym = 0xfefb
let _Pointer_DfltBtnPrev : keysym = 0xfefc
let _ch : keysym = 0xfea0
let _Ch : keysym = 0xfea1
let _CH : keysym = 0xfea2
let _c_h : keysym = 0xfea3
let _C_h : keysym = 0xfea4
let _C_H : keysym = 0xfea5
let _3270_Duplicate : keysym = 0xfd01
let _3270_FieldMark : keysym = 0xfd02
let _3270_Right2 : keysym = 0xfd03
let _3270_Left2 : keysym = 0xfd04
let _3270_BackTab : keysym = 0xfd05
let _3270_EraseEOF : keysym = 0xfd06
let _3270_EraseInput : keysym = 0xfd07
let _3270_Reset : keysym = 0xfd08
let _3270_Quit : keysym = 0xfd09
let _3270_PA1 : keysym = 0xfd0a
let _3270_PA2 : keysym = 0xfd0b
let _3270_PA3 : keysym = 0xfd0c
let _3270_Test : keysym = 0xfd0d
let _3270_Attn : keysym = 0xfd0e
let _3270_CursorBlink : keysym = 0xfd0f
let _3270_AltCursor : keysym = 0xfd10
let _3270_KeyClick : keysym = 0xfd11
let _3270_Jump : keysym = 0xfd12
let _3270_Ident : keysym = 0xfd13
let _3270_Rule : keysym = 0xfd14
let _3270_Copy : keysym = 0xfd15
let _3270_Play : keysym = 0xfd16
let _3270_Setup : keysym = 0xfd17
let _3270_Record : keysym = 0xfd18
let _3270_ChangeScreen : keysym = 0xfd19
let _3270_DeleteWord : keysym = 0xfd1a
let _3270_ExSelect : keysym = 0xfd1b
let _3270_CursorSelect : keysym = 0xfd1c
let _3270_PrintScreen : keysym = 0xfd1d
let _3270_Enter : keysym = 0xfd1e
let _space : keysym = 0x020
let _exclam : keysym = 0x021
let _quotedbl : keysym = 0x022
let _numbersign : keysym = 0x023
let _dollar : keysym = 0x024
let _percent : keysym = 0x025
let _ampersand : keysym = 0x026
let _apostrophe : keysym = 0x027
let _quoteright : keysym = 0x027
let _parenleft : keysym = 0x028
let _parenright : keysym = 0x029
let _asterisk : keysym = 0x02a
let _plus : keysym = 0x02b
let _comma : keysym = 0x02c
let _minus : keysym = 0x02d
let _period : keysym = 0x02e
let _slash : keysym = 0x02f
let _0 : keysym = 0x030
let _1 : keysym = 0x031
let _2 : keysym = 0x032
let _3 : keysym = 0x033
let _4 : keysym = 0x034
let _5 : keysym = 0x035
let _6 : keysym = 0x036
let _7 : keysym = 0x037
let _8 : keysym = 0x038
let _9 : keysym = 0x039
let _colon : keysym = 0x03a
let _semicolon : keysym = 0x03b
let _less : keysym = 0x03c
let _equal : keysym = 0x03d
let _greater : keysym = 0x03e
let _question : keysym = 0x03f
let _at : keysym = 0x040
let _A : keysym = 0x041
let _B : keysym = 0x042
let _C : keysym = 0x043
let _D : keysym = 0x044
let _E : keysym = 0x045
let _F : keysym = 0x046
let _G : keysym = 0x047
let _H : keysym = 0x048
let _I : keysym = 0x049
let _J : keysym = 0x04a
let _K : keysym = 0x04b
let _L : keysym = 0x04c
let _M : keysym = 0x04d
let _N : keysym = 0x04e
let _O : keysym = 0x04f
let _P : keysym = 0x050
let _Q : keysym = 0x051
let _R : keysym = 0x052
let _S : keysym = 0x053
let _T : keysym = 0x054
let _U : keysym = 0x055
let _V : keysym = 0x056
let _W : keysym = 0x057
let _X : keysym = 0x058
let _Y : keysym = 0x059
let _Z : keysym = 0x05a
let _bracketleft : keysym = 0x05b
let _backslash : keysym = 0x05c
let _bracketright : keysym = 0x05d
let _asciicircum : keysym = 0x05e
let _underscore : keysym = 0x05f
let _grave : keysym = 0x060
let _quoteleft : keysym = 0x060
let _a : keysym = 0x061
let _b : keysym = 0x062
let _c : keysym = 0x063
let _d : keysym = 0x064
let _e : keysym = 0x065
let _f : keysym = 0x066
let _g : keysym = 0x067
let _h : keysym = 0x068
let _i : keysym = 0x069
let _j : keysym = 0x06a
let _k : keysym = 0x06b
let _l : keysym = 0x06c
let _m : keysym = 0x06d
let _n : keysym = 0x06e
let _o : keysym = 0x06f
let _p : keysym = 0x070
let _q : keysym = 0x071
let _r : keysym = 0x072
let _s : keysym = 0x073
let _t : keysym = 0x074
let _u : keysym = 0x075
let _v : keysym = 0x076
let _w : keysym = 0x077
let _x : keysym = 0x078
let _y : keysym = 0x079
let _z : keysym = 0x07a
let _braceleft : keysym = 0x07b
let _bar : keysym = 0x07c
let _braceright : keysym = 0x07d
let _asciitilde : keysym = 0x07e
let _nobreakspace : keysym = 0x0a0
let _exclamdown : keysym = 0x0a1
let _cent : keysym = 0x0a2
let _sterling : keysym = 0x0a3
let _currency : keysym = 0x0a4
let _yen : keysym = 0x0a5
let _brokenbar : keysym = 0x0a6
let _section : keysym = 0x0a7
let _diaeresis : keysym = 0x0a8
let _copyright : keysym = 0x0a9
let _ordfeminine : keysym = 0x0aa
let _guillemotleft : keysym = 0x0ab
let _notsign : keysym = 0x0ac
let _hyphen : keysym = 0x0ad
let _registered : keysym = 0x0ae
let _macron : keysym = 0x0af
let _degree : keysym = 0x0b0
let _plusminus : keysym = 0x0b1
let _twosuperior : keysym = 0x0b2
let _threesuperior : keysym = 0x0b3
let _acute : keysym = 0x0b4
let _mu : keysym = 0x0b5
let _paragraph : keysym = 0x0b6
let _periodcentered : keysym = 0x0b7
let _cedilla : keysym = 0x0b8
let _onesuperior : keysym = 0x0b9
let _masculine : keysym = 0x0ba
let _guillemotright : keysym = 0x0bb
let _onequarter : keysym = 0x0bc
let _onehalf : keysym = 0x0bd
let _threequarters : keysym = 0x0be
let _questiondown : keysym = 0x0bf
let _Agrave : keysym = 0x0c0
let _Aacute : keysym = 0x0c1
let _Acircumflex : keysym = 0x0c2
let _Atilde : keysym = 0x0c3
let _Adiaeresis : keysym = 0x0c4
let _Aring : keysym = 0x0c5
let _AE : keysym = 0x0c6
let _Ccedilla : keysym = 0x0c7
let _Egrave : keysym = 0x0c8
let _Eacute : keysym = 0x0c9
let _Ecircumflex : keysym = 0x0ca
let _Ediaeresis : keysym = 0x0cb
let _Igrave : keysym = 0x0cc
let _Iacute : keysym = 0x0cd
let _Icircumflex : keysym = 0x0ce
let _Idiaeresis : keysym = 0x0cf
let _ETH : keysym = 0x0d0
let _Eth : keysym = 0x0d0
let _Ntilde : keysym = 0x0d1
let _Ograve : keysym = 0x0d2
let _Oacute : keysym = 0x0d3
let _Ocircumflex : keysym = 0x0d4
let _Otilde : keysym = 0x0d5
let _Odiaeresis : keysym = 0x0d6
let _multiply : keysym = 0x0d7
let _Oslash : keysym = 0x0d8
let _Ooblique : keysym = 0x0d8
let _Ugrave : keysym = 0x0d9
let _Uacute : keysym = 0x0da
let _Ucircumflex : keysym = 0x0db
let _Udiaeresis : keysym = 0x0dc
let _Yacute : keysym = 0x0dd
let _THORN : keysym = 0x0de
let _Thorn : keysym = 0x0de
let _ssharp : keysym = 0x0df
let _agrave : keysym = 0x0e0
let _aacute : keysym = 0x0e1
let _acircumflex : keysym = 0x0e2
let _atilde : keysym = 0x0e3
let _adiaeresis : keysym = 0x0e4
let _aring : keysym = 0x0e5
let _ae : keysym = 0x0e6
let _ccedilla : keysym = 0x0e7
let _egrave : keysym = 0x0e8
let _eacute : keysym = 0x0e9
let _ecircumflex : keysym = 0x0ea
let _ediaeresis : keysym = 0x0eb
let _igrave : keysym = 0x0ec
let _iacute : keysym = 0x0ed
let _icircumflex : keysym = 0x0ee
let _idiaeresis : keysym = 0x0ef
let _eth : keysym = 0x0f0
let _ntilde : keysym = 0x0f1
let _ograve : keysym = 0x0f2
let _oacute : keysym = 0x0f3
let _ocircumflex : keysym = 0x0f4
let _otilde : keysym = 0x0f5
let _odiaeresis : keysym = 0x0f6
let _division : keysym = 0x0f7
let _oslash : keysym = 0x0f8
let _ooblique : keysym = 0x0f8
let _ugrave : keysym = 0x0f9
let _uacute : keysym = 0x0fa
let _ucircumflex : keysym = 0x0fb
let _udiaeresis : keysym = 0x0fc
let _yacute : keysym = 0x0fd
let _thorn : keysym = 0x0fe
let _ydiaeresis : keysym = 0x0ff
let _Aogonek : keysym = 0x1a1
let _breve : keysym = 0x1a2
let _Lstroke : keysym = 0x1a3
let _Lcaron : keysym = 0x1a5
let _Sacute : keysym = 0x1a6
let _Scaron : keysym = 0x1a9
let _Scedilla : keysym = 0x1aa
let _Tcaron : keysym = 0x1ab
let _Zacute : keysym = 0x1ac
let _Zcaron : keysym = 0x1ae
let _Zabovedot : keysym = 0x1af
let _aogonek : keysym = 0x1b1
let _ogonek : keysym = 0x1b2
let _lstroke : keysym = 0x1b3
let _lcaron : keysym = 0x1b5
let _sacute : keysym = 0x1b6
let _caron : keysym = 0x1b7
let _scaron : keysym = 0x1b9
let _scedilla : keysym = 0x1ba
let _tcaron : keysym = 0x1bb
let _zacute : keysym = 0x1bc
let _doubleacute : keysym = 0x1bd
let _zcaron : keysym = 0x1be
let _zabovedot : keysym = 0x1bf
let _Racute : keysym = 0x1c0
let _Abreve : keysym = 0x1c3
let _Lacute : keysym = 0x1c5
let _Cacute : keysym = 0x1c6
let _Ccaron : keysym = 0x1c8
let _Eogonek : keysym = 0x1ca
let _Ecaron : keysym = 0x1cc
let _Dcaron : keysym = 0x1cf
let _Dstroke : keysym = 0x1d0
let _Nacute : keysym = 0x1d1
let _Ncaron : keysym = 0x1d2
let _Odoubleacute : keysym = 0x1d5
let _Rcaron : keysym = 0x1d8
let _Uring : keysym = 0x1d9
let _Udoubleacute : keysym = 0x1db
let _Tcedilla : keysym = 0x1de
let _racute : keysym = 0x1e0
let _abreve : keysym = 0x1e3
let _lacute : keysym = 0x1e5
let _cacute : keysym = 0x1e6
let _ccaron : keysym = 0x1e8
let _eogonek : keysym = 0x1ea
let _ecaron : keysym = 0x1ec
let _dcaron : keysym = 0x1ef
let _dstroke : keysym = 0x1f0
let _nacute : keysym = 0x1f1
let _ncaron : keysym = 0x1f2
let _odoubleacute : keysym = 0x1f5
let _rcaron : keysym = 0x1f8
let _uring : keysym = 0x1f9
let _udoubleacute : keysym = 0x1fb
let _tcedilla : keysym = 0x1fe
let _abovedot : keysym = 0x1ff
let _Hstroke : keysym = 0x2a1
let _Hcircumflex : keysym = 0x2a6
let _Iabovedot : keysym = 0x2a9
let _Gbreve : keysym = 0x2ab
let _Jcircumflex : keysym = 0x2ac
let _hstroke : keysym = 0x2b1
let _hcircumflex : keysym = 0x2b6
let _idotless : keysym = 0x2b9
let _gbreve : keysym = 0x2bb
let _jcircumflex : keysym = 0x2bc
let _Cabovedot : keysym = 0x2c5
let _Ccircumflex : keysym = 0x2c6
let _Gabovedot : keysym = 0x2d5
let _Gcircumflex : keysym = 0x2d8
let _Ubreve : keysym = 0x2dd
let _Scircumflex : keysym = 0x2de
let _cabovedot : keysym = 0x2e5
let _ccircumflex : keysym = 0x2e6
let _gabovedot : keysym = 0x2f5
let _gcircumflex : keysym = 0x2f8
let _ubreve : keysym = 0x2fd
let _scircumflex : keysym = 0x2fe
let _kra : keysym = 0x3a2
let _kappa : keysym = 0x3a2
let _Rcedilla : keysym = 0x3a3
let _Itilde : keysym = 0x3a5
let _Lcedilla : keysym = 0x3a6
let _Emacron : keysym = 0x3aa
let _Gcedilla : keysym = 0x3ab
let _Tslash : keysym = 0x3ac
let _rcedilla : keysym = 0x3b3
let _itilde : keysym = 0x3b5
let _lcedilla : keysym = 0x3b6
let _emacron : keysym = 0x3ba
let _gcedilla : keysym = 0x3bb
let _tslash : keysym = 0x3bc
let _ENG : keysym = 0x3bd
let _eng : keysym = 0x3bf
let _Amacron : keysym = 0x3c0
let _Iogonek : keysym = 0x3c7
let _Eabovedot : keysym = 0x3cc
let _Imacron : keysym = 0x3cf
let _Ncedilla : keysym = 0x3d1
let _Omacron : keysym = 0x3d2
let _Kcedilla : keysym = 0x3d3
let _Uogonek : keysym = 0x3d9
let _Utilde : keysym = 0x3dd
let _Umacron : keysym = 0x3de
let _amacron : keysym = 0x3e0
let _iogonek : keysym = 0x3e7
let _eabovedot : keysym = 0x3ec
let _imacron : keysym = 0x3ef
let _ncedilla : keysym = 0x3f1
let _omacron : keysym = 0x3f2
let _kcedilla : keysym = 0x3f3
let _uogonek : keysym = 0x3f9
let _utilde : keysym = 0x3fd
let _umacron : keysym = 0x3fe
let _Wcircumflex : keysym = 0x1000174
let _wcircumflex : keysym = 0x1000175
let _Ycircumflex : keysym = 0x1000176
let _ycircumflex : keysym = 0x1000177
let _Babovedot : keysym = 0x1001e02
let _babovedot : keysym = 0x1001e03
let _Dabovedot : keysym = 0x1001e0a
let _dabovedot : keysym = 0x1001e0b
let _Fabovedot : keysym = 0x1001e1e
let _fabovedot : keysym = 0x1001e1f
let _Mabovedot : keysym = 0x1001e40
let _mabovedot : keysym = 0x1001e41
let _Pabovedot : keysym = 0x1001e56
let _pabovedot : keysym = 0x1001e57
let _Sabovedot : keysym = 0x1001e60
let _sabovedot : keysym = 0x1001e61
let _Tabovedot : keysym = 0x1001e6a
let _tabovedot : keysym = 0x1001e6b
let _Wgrave : keysym = 0x1001e80
let _wgrave : keysym = 0x1001e81
let _Wacute : keysym = 0x1001e82
let _wacute : keysym = 0x1001e83
let _Wdiaeresis : keysym = 0x1001e84
let _wdiaeresis : keysym = 0x1001e85
let _Ygrave : keysym = 0x1001ef2
let _ygrave : keysym = 0x1001ef3
let _OE : keysym = 0x13bc
let _oe : keysym = 0x13bd
let _Ydiaeresis : keysym = 0x13be
let _overline : keysym = 0x47e
let _kana_fullstop : keysym = 0x4a1
let _kana_openingbracket : keysym = 0x4a2
let _kana_closingbracket : keysym = 0x4a3
let _kana_comma : keysym = 0x4a4
let _kana_conjunctive : keysym = 0x4a5
let _kana_middledot : keysym = 0x4a5
let _kana_WO : keysym = 0x4a6
let _kana_a : keysym = 0x4a7
let _kana_i : keysym = 0x4a8
let _kana_u : keysym = 0x4a9
let _kana_e : keysym = 0x4aa
let _kana_o : keysym = 0x4ab
let _kana_ya : keysym = 0x4ac
let _kana_yu : keysym = 0x4ad
let _kana_yo : keysym = 0x4ae
let _kana_tsu : keysym = 0x4af
let _kana_tu : keysym = 0x4af
let _prolongedsound : keysym = 0x4b0
let _kana_A : keysym = 0x4b1
let _kana_I : keysym = 0x4b2
let _kana_U : keysym = 0x4b3
let _kana_E : keysym = 0x4b4
let _kana_O : keysym = 0x4b5
let _kana_KA : keysym = 0x4b6
let _kana_KI : keysym = 0x4b7
let _kana_KU : keysym = 0x4b8
let _kana_KE : keysym = 0x4b9
let _kana_KO : keysym = 0x4ba
let _kana_SA : keysym = 0x4bb
let _kana_SHI : keysym = 0x4bc
let _kana_SU : keysym = 0x4bd
let _kana_SE : keysym = 0x4be
let _kana_SO : keysym = 0x4bf
let _kana_TA : keysym = 0x4c0
let _kana_CHI : keysym = 0x4c1
let _kana_TI : keysym = 0x4c1
let _kana_TSU : keysym = 0x4c2
let _kana_TU : keysym = 0x4c2
let _kana_TE : keysym = 0x4c3
let _kana_TO : keysym = 0x4c4
let _kana_NA : keysym = 0x4c5
let _kana_NI : keysym = 0x4c6
let _kana_NU : keysym = 0x4c7
let _kana_NE : keysym = 0x4c8
let _kana_NO : keysym = 0x4c9
let _kana_HA : keysym = 0x4ca
let _kana_HI : keysym = 0x4cb
let _kana_FU : keysym = 0x4cc
let _kana_HU : keysym = 0x4cc
let _kana_HE : keysym = 0x4cd
let _kana_HO : keysym = 0x4ce
let _kana_MA : keysym = 0x4cf
let _kana_MI : keysym = 0x4d0
let _kana_MU : keysym = 0x4d1
let _kana_ME : keysym = 0x4d2
let _kana_MO : keysym = 0x4d3
let _kana_YA : keysym = 0x4d4
let _kana_YU : keysym = 0x4d5
let _kana_YO : keysym = 0x4d6
let _kana_RA : keysym = 0x4d7
let _kana_RI : keysym = 0x4d8
let _kana_RU : keysym = 0x4d9
let _kana_RE : keysym = 0x4da
let _kana_RO : keysym = 0x4db
let _kana_WA : keysym = 0x4dc
let _kana_N : keysym = 0x4dd
let _voicedsound : keysym = 0x4de
let _semivoicedsound : keysym = 0x4df
let _kana_switch : keysym = 0xff7e
let _Farsi_0 : keysym = 0x10006f0
let _Farsi_1 : keysym = 0x10006f1
let _Farsi_2 : keysym = 0x10006f2
let _Farsi_3 : keysym = 0x10006f3
let _Farsi_4 : keysym = 0x10006f4
let _Farsi_5 : keysym = 0x10006f5
let _Farsi_6 : keysym = 0x10006f6
let _Farsi_7 : keysym = 0x10006f7
let _Farsi_8 : keysym = 0x10006f8
let _Farsi_9 : keysym = 0x10006f9
let _Arabic_percent : keysym = 0x100066a
let _Arabic_superscript_alef : keysym = 0x1000670
let _Arabic_tteh : keysym = 0x1000679
let _Arabic_peh : keysym = 0x100067e
let _Arabic_tcheh : keysym = 0x1000686
let _Arabic_ddal : keysym = 0x1000688
let _Arabic_rreh : keysym = 0x1000691
let _Arabic_comma : keysym = 0x5ac
let _Arabic_fullstop : keysym = 0x10006d4
let _Arabic_0 : keysym = 0x1000660
let _Arabic_1 : keysym = 0x1000661
let _Arabic_2 : keysym = 0x1000662
let _Arabic_3 : keysym = 0x1000663
let _Arabic_4 : keysym = 0x1000664
let _Arabic_5 : keysym = 0x1000665
let _Arabic_6 : keysym = 0x1000666
let _Arabic_7 : keysym = 0x1000667
let _Arabic_8 : keysym = 0x1000668
let _Arabic_9 : keysym = 0x1000669
let _Arabic_semicolon : keysym = 0x5bb
let _Arabic_question_mark : keysym = 0x5bf
let _Arabic_hamza : keysym = 0x5c1
let _Arabic_maddaonalef : keysym = 0x5c2
let _Arabic_hamzaonalef : keysym = 0x5c3
let _Arabic_hamzaonwaw : keysym = 0x5c4
let _Arabic_hamzaunderalef : keysym = 0x5c5
let _Arabic_hamzaonyeh : keysym = 0x5c6
let _Arabic_alef : keysym = 0x5c7
let _Arabic_beh : keysym = 0x5c8
let _Arabic_tehmarbuta : keysym = 0x5c9
let _Arabic_teh : keysym = 0x5ca
let _Arabic_theh : keysym = 0x5cb
let _Arabic_jeem : keysym = 0x5cc
let _Arabic_hah : keysym = 0x5cd
let _Arabic_khah : keysym = 0x5ce
let _Arabic_dal : keysym = 0x5cf
let _Arabic_thal : keysym = 0x5d0
let _Arabic_ra : keysym = 0x5d1
let _Arabic_zain : keysym = 0x5d2
let _Arabic_seen : keysym = 0x5d3
let _Arabic_sheen : keysym = 0x5d4
let _Arabic_sad : keysym = 0x5d5
let _Arabic_dad : keysym = 0x5d6
let _Arabic_tah : keysym = 0x5d7
let _Arabic_zah : keysym = 0x5d8
let _Arabic_ain : keysym = 0x5d9
let _Arabic_ghain : keysym = 0x5da
let _Arabic_tatweel : keysym = 0x5e0
let _Arabic_feh : keysym = 0x5e1
let _Arabic_qaf : keysym = 0x5e2
let _Arabic_kaf : keysym = 0x5e3
let _Arabic_lam : keysym = 0x5e4
let _Arabic_meem : keysym = 0x5e5
let _Arabic_noon : keysym = 0x5e6
let _Arabic_ha : keysym = 0x5e7
let _Arabic_heh : keysym = 0x5e7
let _Arabic_waw : keysym = 0x5e8
let _Arabic_alefmaksura : keysym = 0x5e9
let _Arabic_yeh : keysym = 0x5ea
let _Arabic_fathatan : keysym = 0x5eb
let _Arabic_dammatan : keysym = 0x5ec
let _Arabic_kasratan : keysym = 0x5ed
let _Arabic_fatha : keysym = 0x5ee
let _Arabic_damma : keysym = 0x5ef
let _Arabic_kasra : keysym = 0x5f0
let _Arabic_shadda : keysym = 0x5f1
let _Arabic_sukun : keysym = 0x5f2
let _Arabic_madda_above : keysym = 0x1000653
let _Arabic_hamza_above : keysym = 0x1000654
let _Arabic_hamza_below : keysym = 0x1000655
let _Arabic_jeh : keysym = 0x1000698
let _Arabic_veh : keysym = 0x10006a4
let _Arabic_keheh : keysym = 0x10006a9
let _Arabic_gaf : keysym = 0x10006af
let _Arabic_noon_ghunna : keysym = 0x10006ba
let _Arabic_heh_doachashmee : keysym = 0x10006be
let _Farsi_yeh : keysym = 0x10006cc
let _Arabic_farsi_yeh : keysym = 0x10006cc
let _Arabic_yeh_baree : keysym = 0x10006d2
let _Arabic_heh_goal : keysym = 0x10006c1
let _Arabic_switch : keysym = 0xff7e
let _Cyrillic_GHE_bar : keysym = 0x1000492
let _Cyrillic_ghe_bar : keysym = 0x1000493
let _Cyrillic_ZHE_descender : keysym = 0x1000496
let _Cyrillic_zhe_descender : keysym = 0x1000497
let _Cyrillic_KA_descender : keysym = 0x100049a
let _Cyrillic_ka_descender : keysym = 0x100049b
let _Cyrillic_KA_vertstroke : keysym = 0x100049c
let _Cyrillic_ka_vertstroke : keysym = 0x100049d
let _Cyrillic_EN_descender : keysym = 0x10004a2
let _Cyrillic_en_descender : keysym = 0x10004a3
let _Cyrillic_U_straight : keysym = 0x10004ae
let _Cyrillic_u_straight : keysym = 0x10004af
let _Cyrillic_U_straight_bar : keysym = 0x10004b0
let _Cyrillic_u_straight_bar : keysym = 0x10004b1
let _Cyrillic_HA_descender : keysym = 0x10004b2
let _Cyrillic_ha_descender : keysym = 0x10004b3
let _Cyrillic_CHE_descender : keysym = 0x10004b6
let _Cyrillic_che_descender : keysym = 0x10004b7
let _Cyrillic_CHE_vertstroke : keysym = 0x10004b8
let _Cyrillic_che_vertstroke : keysym = 0x10004b9
let _Cyrillic_SHHA : keysym = 0x10004ba
let _Cyrillic_shha : keysym = 0x10004bb
let _Cyrillic_SCHWA : keysym = 0x10004d8
let _Cyrillic_schwa : keysym = 0x10004d9
let _Cyrillic_I_macron : keysym = 0x10004e2
let _Cyrillic_i_macron : keysym = 0x10004e3
let _Cyrillic_O_bar : keysym = 0x10004e8
let _Cyrillic_o_bar : keysym = 0x10004e9
let _Cyrillic_U_macron : keysym = 0x10004ee
let _Cyrillic_u_macron : keysym = 0x10004ef
let _Serbian_dje : keysym = 0x6a1
let _Macedonia_gje : keysym = 0x6a2
let _Cyrillic_io : keysym = 0x6a3
let _Ukrainian_ie : keysym = 0x6a4
let _Ukranian_je : keysym = 0x6a4
let _Macedonia_dse : keysym = 0x6a5
let _Ukrainian_i : keysym = 0x6a6
let _Ukranian_i : keysym = 0x6a6
let _Ukrainian_yi : keysym = 0x6a7
let _Ukranian_yi : keysym = 0x6a7
let _Cyrillic_je : keysym = 0x6a8
let _Serbian_je : keysym = 0x6a8
let _Cyrillic_lje : keysym = 0x6a9
let _Serbian_lje : keysym = 0x6a9
let _Cyrillic_nje : keysym = 0x6aa
let _Serbian_nje : keysym = 0x6aa
let _Serbian_tshe : keysym = 0x6ab
let _Macedonia_kje : keysym = 0x6ac
let _Ukrainian_ghe_with_upturn : keysym = 0x6ad
let _Byelorussian_shortu : keysym = 0x6ae
let _Cyrillic_dzhe : keysym = 0x6af
let _Serbian_dze : keysym = 0x6af
let _numerosign : keysym = 0x6b0
let _Serbian_DJE : keysym = 0x6b1
let _Macedonia_GJE : keysym = 0x6b2
let _Cyrillic_IO : keysym = 0x6b3
let _Ukrainian_IE : keysym = 0x6b4
let _Ukranian_JE : keysym = 0x6b4
let _Macedonia_DSE : keysym = 0x6b5
let _Ukrainian_I : keysym = 0x6b6
let _Ukranian_I : keysym = 0x6b6
let _Ukrainian_YI : keysym = 0x6b7
let _Ukranian_YI : keysym = 0x6b7
let _Cyrillic_JE : keysym = 0x6b8
let _Serbian_JE : keysym = 0x6b8
let _Cyrillic_LJE : keysym = 0x6b9
let _Serbian_LJE : keysym = 0x6b9
let _Cyrillic_NJE : keysym = 0x6ba
let _Serbian_NJE : keysym = 0x6ba
let _Serbian_TSHE : keysym = 0x6bb
let _Macedonia_KJE : keysym = 0x6bc
let _Ukrainian_GHE_WITH_UPTURN : keysym = 0x6bd
let _Byelorussian_SHORTU : keysym = 0x6be
let _Cyrillic_DZHE : keysym = 0x6bf
let _Serbian_DZE : keysym = 0x6bf
let _Cyrillic_yu : keysym = 0x6c0
let _Cyrillic_a : keysym = 0x6c1
let _Cyrillic_be : keysym = 0x6c2
let _Cyrillic_tse : keysym = 0x6c3
let _Cyrillic_de : keysym = 0x6c4
let _Cyrillic_ie : keysym = 0x6c5
let _Cyrillic_ef : keysym = 0x6c6
let _Cyrillic_ghe : keysym = 0x6c7
let _Cyrillic_ha : keysym = 0x6c8
let _Cyrillic_i : keysym = 0x6c9
let _Cyrillic_shorti : keysym = 0x6ca
let _Cyrillic_ka : keysym = 0x6cb
let _Cyrillic_el : keysym = 0x6cc
let _Cyrillic_em : keysym = 0x6cd
let _Cyrillic_en : keysym = 0x6ce
let _Cyrillic_o : keysym = 0x6cf
let _Cyrillic_pe : keysym = 0x6d0
let _Cyrillic_ya : keysym = 0x6d1
let _Cyrillic_er : keysym = 0x6d2
let _Cyrillic_es : keysym = 0x6d3
let _Cyrillic_te : keysym = 0x6d4
let _Cyrillic_u : keysym = 0x6d5
let _Cyrillic_zhe : keysym = 0x6d6
let _Cyrillic_ve : keysym = 0x6d7
let _Cyrillic_softsign : keysym = 0x6d8
let _Cyrillic_yeru : keysym = 0x6d9
let _Cyrillic_ze : keysym = 0x6da
let _Cyrillic_sha : keysym = 0x6db
let _Cyrillic_e : keysym = 0x6dc
let _Cyrillic_shcha : keysym = 0x6dd
let _Cyrillic_che : keysym = 0x6de
let _Cyrillic_hardsign : keysym = 0x6df
let _Cyrillic_YU : keysym = 0x6e0
let _Cyrillic_A : keysym = 0x6e1
let _Cyrillic_BE : keysym = 0x6e2
let _Cyrillic_TSE : keysym = 0x6e3
let _Cyrillic_DE : keysym = 0x6e4
let _Cyrillic_IE : keysym = 0x6e5
let _Cyrillic_EF : keysym = 0x6e6
let _Cyrillic_GHE : keysym = 0x6e7
let _Cyrillic_HA : keysym = 0x6e8
let _Cyrillic_I : keysym = 0x6e9
let _Cyrillic_SHORTI : keysym = 0x6ea
let _Cyrillic_KA : keysym = 0x6eb
let _Cyrillic_EL : keysym = 0x6ec
let _Cyrillic_EM : keysym = 0x6ed
let _Cyrillic_EN : keysym = 0x6ee
let _Cyrillic_O : keysym = 0x6ef
let _Cyrillic_PE : keysym = 0x6f0
let _Cyrillic_YA : keysym = 0x6f1
let _Cyrillic_ER : keysym = 0x6f2
let _Cyrillic_ES : keysym = 0x6f3
let _Cyrillic_TE : keysym = 0x6f4
let _Cyrillic_U : keysym = 0x6f5
let _Cyrillic_ZHE : keysym = 0x6f6
let _Cyrillic_VE : keysym = 0x6f7
let _Cyrillic_SOFTSIGN : keysym = 0x6f8
let _Cyrillic_YERU : keysym = 0x6f9
let _Cyrillic_ZE : keysym = 0x6fa
let _Cyrillic_SHA : keysym = 0x6fb
let _Cyrillic_E : keysym = 0x6fc
let _Cyrillic_SHCHA : keysym = 0x6fd
let _Cyrillic_CHE : keysym = 0x6fe
let _Cyrillic_HARDSIGN : keysym = 0x6ff
let _Greek_ALPHAaccent : keysym = 0x7a1
let _Greek_EPSILONaccent : keysym = 0x7a2
let _Greek_ETAaccent : keysym = 0x7a3
let _Greek_IOTAaccent : keysym = 0x7a4
let _Greek_IOTAdieresis : keysym = 0x7a5
let _Greek_IOTAdiaeresis : keysym = 0x7a5
let _Greek_OMICRONaccent : keysym = 0x7a7
let _Greek_UPSILONaccent : keysym = 0x7a8
let _Greek_UPSILONdieresis : keysym = 0x7a9
let _Greek_OMEGAaccent : keysym = 0x7ab
let _Greek_accentdieresis : keysym = 0x7ae
let _Greek_horizbar : keysym = 0x7af
let _Greek_alphaaccent : keysym = 0x7b1
let _Greek_epsilonaccent : keysym = 0x7b2
let _Greek_etaaccent : keysym = 0x7b3
let _Greek_iotaaccent : keysym = 0x7b4
let _Greek_iotadieresis : keysym = 0x7b5
let _Greek_iotaaccentdieresis : keysym = 0x7b6
let _Greek_omicronaccent : keysym = 0x7b7
let _Greek_upsilonaccent : keysym = 0x7b8
let _Greek_upsilondieresis : keysym = 0x7b9
let _Greek_upsilonaccentdieresis : keysym = 0x7ba
let _Greek_omegaaccent : keysym = 0x7bb
let _Greek_ALPHA : keysym = 0x7c1
let _Greek_BETA : keysym = 0x7c2
let _Greek_GAMMA : keysym = 0x7c3
let _Greek_DELTA : keysym = 0x7c4
let _Greek_EPSILON : keysym = 0x7c5
let _Greek_ZETA : keysym = 0x7c6
let _Greek_ETA : keysym = 0x7c7
let _Greek_THETA : keysym = 0x7c8
let _Greek_IOTA : keysym = 0x7c9
let _Greek_KAPPA : keysym = 0x7ca
let _Greek_LAMDA : keysym = 0x7cb
let _Greek_LAMBDA : keysym = 0x7cb
let _Greek_MU : keysym = 0x7cc
let _Greek_NU : keysym = 0x7cd
let _Greek_XI : keysym = 0x7ce
let _Greek_OMICRON : keysym = 0x7cf
let _Greek_PI : keysym = 0x7d0
let _Greek_RHO : keysym = 0x7d1
let _Greek_SIGMA : keysym = 0x7d2
let _Greek_TAU : keysym = 0x7d4
let _Greek_UPSILON : keysym = 0x7d5
let _Greek_PHI : keysym = 0x7d6
let _Greek_CHI : keysym = 0x7d7
let _Greek_PSI : keysym = 0x7d8
let _Greek_OMEGA : keysym = 0x7d9
let _Greek_alpha : keysym = 0x7e1
let _Greek_beta : keysym = 0x7e2
let _Greek_gamma : keysym = 0x7e3
let _Greek_delta : keysym = 0x7e4
let _Greek_epsilon : keysym = 0x7e5
let _Greek_zeta : keysym = 0x7e6
let _Greek_eta : keysym = 0x7e7
let _Greek_theta : keysym = 0x7e8
let _Greek_iota : keysym = 0x7e9
let _Greek_kappa : keysym = 0x7ea
let _Greek_lamda : keysym = 0x7eb
let _Greek_lambda : keysym = 0x7eb
let _Greek_mu : keysym = 0x7ec
let _Greek_nu : keysym = 0x7ed
let _Greek_xi : keysym = 0x7ee
let _Greek_omicron : keysym = 0x7ef
let _Greek_pi : keysym = 0x7f0
let _Greek_rho : keysym = 0x7f1
let _Greek_sigma : keysym = 0x7f2
let _Greek_finalsmallsigma : keysym = 0x7f3
let _Greek_tau : keysym = 0x7f4
let _Greek_upsilon : keysym = 0x7f5
let _Greek_phi : keysym = 0x7f6
let _Greek_chi : keysym = 0x7f7
let _Greek_psi : keysym = 0x7f8
let _Greek_omega : keysym = 0x7f9
let _Greek_switch : keysym = 0xff7e
let _leftradical : keysym = 0x8a1
let _topleftradical : keysym = 0x8a2
let _horizconnector : keysym = 0x8a3
let _topintegral : keysym = 0x8a4
let _botintegral : keysym = 0x8a5
let _vertconnector : keysym = 0x8a6
let _topleftsqbracket : keysym = 0x8a7
let _botleftsqbracket : keysym = 0x8a8
let _toprightsqbracket : keysym = 0x8a9
let _botrightsqbracket : keysym = 0x8aa
let _topleftparens : keysym = 0x8ab
let _botleftparens : keysym = 0x8ac
let _toprightparens : keysym = 0x8ad
let _botrightparens : keysym = 0x8ae
let _leftmiddlecurlybrace : keysym = 0x8af
let _rightmiddlecurlybrace : keysym = 0x8b0
let _topleftsummation : keysym = 0x8b1
let _botleftsummation : keysym = 0x8b2
let _topvertsummationconnector : keysym = 0x8b3
let _botvertsummationconnector : keysym = 0x8b4
let _toprightsummation : keysym = 0x8b5
let _botrightsummation : keysym = 0x8b6
let _rightmiddlesummation : keysym = 0x8b7
let _lessthanequal : keysym = 0x8bc
let _notequal : keysym = 0x8bd
let _greaterthanequal : keysym = 0x8be
let _integral : keysym = 0x8bf
let _therefore : keysym = 0x8c0
let _variation : keysym = 0x8c1
let _infinity : keysym = 0x8c2
let _nabla : keysym = 0x8c5
let _approximate : keysym = 0x8c8
let _similarequal : keysym = 0x8c9
let _ifonlyif : keysym = 0x8cd
let _implies : keysym = 0x8ce
let _identical : keysym = 0x8cf
let _radical : keysym = 0x8d6
let _includedin : keysym = 0x8da
let _includes : keysym = 0x8db
let _intersection : keysym = 0x8dc
let _union : keysym = 0x8dd
let _logicaland : keysym = 0x8de
let _logicalor : keysym = 0x8df
let _partialderivative : keysym = 0x8ef
let _function : keysym = 0x8f6
let _leftarrow : keysym = 0x8fb
let _uparrow : keysym = 0x8fc
let _rightarrow : keysym = 0x8fd
let _downarrow : keysym = 0x8fe
let _blank : keysym = 0x9df
let _soliddiamond : keysym = 0x9e0
let _checkerboard : keysym = 0x9e1
let _ht : keysym = 0x9e2
let _ff : keysym = 0x9e3
let _cr : keysym = 0x9e4
let _lf : keysym = 0x9e5
let _nl : keysym = 0x9e8
let _vt : keysym = 0x9e9
let _lowrightcorner : keysym = 0x9ea
let _uprightcorner : keysym = 0x9eb
let _upleftcorner : keysym = 0x9ec
let _lowleftcorner : keysym = 0x9ed
let _crossinglines : keysym = 0x9ee
let _horizlinescan1 : keysym = 0x9ef
let _horizlinescan3 : keysym = 0x9f0
let _horizlinescan5 : keysym = 0x9f1
let _horizlinescan7 : keysym = 0x9f2
let _horizlinescan9 : keysym = 0x9f3
let _leftt : keysym = 0x9f4
let _rightt : keysym = 0x9f5
let _bott : keysym = 0x9f6
let _topt : keysym = 0x9f7
let _vertbar : keysym = 0x9f8
let _emspace : keysym = 0xaa1
let _enspace : keysym = 0xaa2
let _em3space : keysym = 0xaa3
let _em4space : keysym = 0xaa4
let _digitspace : keysym = 0xaa5
let _punctspace : keysym = 0xaa6
let _thinspace : keysym = 0xaa7
let _hairspace : keysym = 0xaa8
let _emdash : keysym = 0xaa9
let _endash : keysym = 0xaaa
let _signifblank : keysym = 0xaac
let _ellipsis : keysym = 0xaae
let _doubbaselinedot : keysym = 0xaaf
let _onethird : keysym = 0xab0
let _twothirds : keysym = 0xab1
let _onefifth : keysym = 0xab2
let _twofifths : keysym = 0xab3
let _threefifths : keysym = 0xab4
let _fourfifths : keysym = 0xab5
let _onesixth : keysym = 0xab6
let _fivesixths : keysym = 0xab7
let _careof : keysym = 0xab8
let _figdash : keysym = 0xabb
let _leftanglebracket : keysym = 0xabc
let _decimalpoint : keysym = 0xabd
let _rightanglebracket : keysym = 0xabe
let _marker : keysym = 0xabf
let _oneeighth : keysym = 0xac3
let _threeeighths : keysym = 0xac4
let _fiveeighths : keysym = 0xac5
let _seveneighths : keysym = 0xac6
let _trademark : keysym = 0xac9
let _signaturemark : keysym = 0xaca
let _trademarkincircle : keysym = 0xacb
let _leftopentriangle : keysym = 0xacc
let _rightopentriangle : keysym = 0xacd
let _emopencircle : keysym = 0xace
let _emopenrectangle : keysym = 0xacf
let _leftsinglequotemark : keysym = 0xad0
let _rightsinglequotemark : keysym = 0xad1
let _leftdoublequotemark : keysym = 0xad2
let _rightdoublequotemark : keysym = 0xad3
let _prescription : keysym = 0xad4
let _permille : keysym = 0xad5
let _minutes : keysym = 0xad6
let _seconds : keysym = 0xad7
let _latincross : keysym = 0xad9
let _hexagram : keysym = 0xada
let _filledrectbullet : keysym = 0xadb
let _filledlefttribullet : keysym = 0xadc
let _filledrighttribullet : keysym = 0xadd
let _emfilledcircle : keysym = 0xade
let _emfilledrect : keysym = 0xadf
let _enopencircbullet : keysym = 0xae0
let _enopensquarebullet : keysym = 0xae1
let _openrectbullet : keysym = 0xae2
let _opentribulletup : keysym = 0xae3
let _opentribulletdown : keysym = 0xae4
let _openstar : keysym = 0xae5
let _enfilledcircbullet : keysym = 0xae6
let _enfilledsqbullet : keysym = 0xae7
let _filledtribulletup : keysym = 0xae8
let _filledtribulletdown : keysym = 0xae9
let _leftpointer : keysym = 0xaea
let _rightpointer : keysym = 0xaeb
let _club : keysym = 0xaec
let _diamond : keysym = 0xaed
let _heart : keysym = 0xaee
let _maltesecross : keysym = 0xaf0
let _dagger : keysym = 0xaf1
let _doubledagger : keysym = 0xaf2
let _checkmark : keysym = 0xaf3
let _ballotcross : keysym = 0xaf4
let _musicalsharp : keysym = 0xaf5
let _musicalflat : keysym = 0xaf6
let _malesymbol : keysym = 0xaf7
let _femalesymbol : keysym = 0xaf8
let _telephone : keysym = 0xaf9
let _telephonerecorder : keysym = 0xafa
let _phonographcopyright : keysym = 0xafb
let _caret : keysym = 0xafc
let _singlelowquotemark : keysym = 0xafd
let _doublelowquotemark : keysym = 0xafe
let _cursor : keysym = 0xaff
let _leftcaret : keysym = 0xba3
let _rightcaret : keysym = 0xba6
let _downcaret : keysym = 0xba8
let _upcaret : keysym = 0xba9
let _overbar : keysym = 0xbc0
let _downtack : keysym = 0xbc2
let _upshoe : keysym = 0xbc3
let _downstile : keysym = 0xbc4
let _underbar : keysym = 0xbc6
let _jot : keysym = 0xbca
let _quad : keysym = 0xbcc
let _uptack : keysym = 0xbce
let _circle : keysym = 0xbcf
let _upstile : keysym = 0xbd3
let _downshoe : keysym = 0xbd6
let _rightshoe : keysym = 0xbd8
let _leftshoe : keysym = 0xbda
let _lefttack : keysym = 0xbdc
let _righttack : keysym = 0xbfc
let _hebrew_doublelowline : keysym = 0xcdf
let _hebrew_aleph : keysym = 0xce0
let _hebrew_bet : keysym = 0xce1
let _hebrew_beth : keysym = 0xce1
let _hebrew_gimel : keysym = 0xce2
let _hebrew_gimmel : keysym = 0xce2
let _hebrew_dalet : keysym = 0xce3
let _hebrew_daleth : keysym = 0xce3
let _hebrew_he : keysym = 0xce4
let _hebrew_waw : keysym = 0xce5
let _hebrew_zain : keysym = 0xce6
let _hebrew_zayin : keysym = 0xce6
let _hebrew_chet : keysym = 0xce7
let _hebrew_het : keysym = 0xce7
let _hebrew_tet : keysym = 0xce8
let _hebrew_teth : keysym = 0xce8
let _hebrew_yod : keysym = 0xce9
let _hebrew_finalkaph : keysym = 0xcea
let _hebrew_kaph : keysym = 0xceb
let _hebrew_lamed : keysym = 0xcec
let _hebrew_finalmem : keysym = 0xced
let _hebrew_mem : keysym = 0xcee
let _hebrew_finalnun : keysym = 0xcef
let _hebrew_nun : keysym = 0xcf0
let _hebrew_samech : keysym = 0xcf1
let _hebrew_samekh : keysym = 0xcf1
let _hebrew_ayin : keysym = 0xcf2
let _hebrew_finalpe : keysym = 0xcf3
let _hebrew_pe : keysym = 0xcf4
let _hebrew_finalzade : keysym = 0xcf5
let _hebrew_finalzadi : keysym = 0xcf5
let _hebrew_zade : keysym = 0xcf6
let _hebrew_zadi : keysym = 0xcf6
let _hebrew_qoph : keysym = 0xcf7
let _hebrew_kuf : keysym = 0xcf7
let _hebrew_resh : keysym = 0xcf8
let _hebrew_shin : keysym = 0xcf9
let _hebrew_taw : keysym = 0xcfa
let _hebrew_taf : keysym = 0xcfa
let _Hebrew_switch : keysym = 0xff7e
let _Thai_kokai : keysym = 0xda1
let _Thai_khokhai : keysym = 0xda2
let _Thai_khokhuat : keysym = 0xda3
let _Thai_khokhwai : keysym = 0xda4
let _Thai_khokhon : keysym = 0xda5
let _Thai_khorakhang : keysym = 0xda6
let _Thai_ngongu : keysym = 0xda7
let _Thai_chochan : keysym = 0xda8
let _Thai_choching : keysym = 0xda9
let _Thai_chochang : keysym = 0xdaa
let _Thai_soso : keysym = 0xdab
let _Thai_chochoe : keysym = 0xdac
let _Thai_yoying : keysym = 0xdad
let _Thai_dochada : keysym = 0xdae
let _Thai_topatak : keysym = 0xdaf
let _Thai_thothan : keysym = 0xdb0
let _Thai_thonangmontho : keysym = 0xdb1
let _Thai_thophuthao : keysym = 0xdb2
let _Thai_nonen : keysym = 0xdb3
let _Thai_dodek : keysym = 0xdb4
let _Thai_totao : keysym = 0xdb5
let _Thai_thothung : keysym = 0xdb6
let _Thai_thothahan : keysym = 0xdb7
let _Thai_thothong : keysym = 0xdb8
let _Thai_nonu : keysym = 0xdb9
let _Thai_bobaimai : keysym = 0xdba
let _Thai_popla : keysym = 0xdbb
let _Thai_phophung : keysym = 0xdbc
let _Thai_fofa : keysym = 0xdbd
let _Thai_phophan : keysym = 0xdbe
let _Thai_fofan : keysym = 0xdbf
let _Thai_phosamphao : keysym = 0xdc0
let _Thai_moma : keysym = 0xdc1
let _Thai_yoyak : keysym = 0xdc2
let _Thai_rorua : keysym = 0xdc3
let _Thai_ru : keysym = 0xdc4
let _Thai_loling : keysym = 0xdc5
let _Thai_lu : keysym = 0xdc6
let _Thai_wowaen : keysym = 0xdc7
let _Thai_sosala : keysym = 0xdc8
let _Thai_sorusi : keysym = 0xdc9
let _Thai_sosua : keysym = 0xdca
let _Thai_hohip : keysym = 0xdcb
let _Thai_lochula : keysym = 0xdcc
let _Thai_oang : keysym = 0xdcd
let _Thai_honokhuk : keysym = 0xdce
let _Thai_paiyannoi : keysym = 0xdcf
let _Thai_saraa : keysym = 0xdd0
let _Thai_maihanakat : keysym = 0xdd1
let _Thai_saraaa : keysym = 0xdd2
let _Thai_saraam : keysym = 0xdd3
let _Thai_sarai : keysym = 0xdd4
let _Thai_saraii : keysym = 0xdd5
let _Thai_saraue : keysym = 0xdd6
let _Thai_sarauee : keysym = 0xdd7
let _Thai_sarau : keysym = 0xdd8
let _Thai_sarauu : keysym = 0xdd9
let _Thai_phinthu : keysym = 0xdda
let _Thai_maihanakat_maitho : keysym = 0xdde
let _Thai_baht : keysym = 0xddf
let _Thai_sarae : keysym = 0xde0
let _Thai_saraae : keysym = 0xde1
let _Thai_sarao : keysym = 0xde2
let _Thai_saraaimaimuan : keysym = 0xde3
let _Thai_saraaimaimalai : keysym = 0xde4
let _Thai_lakkhangyao : keysym = 0xde5
let _Thai_maiyamok : keysym = 0xde6
let _Thai_maitaikhu : keysym = 0xde7
let _Thai_maiek : keysym = 0xde8
let _Thai_maitho : keysym = 0xde9
let _Thai_maitri : keysym = 0xdea
let _Thai_maichattawa : keysym = 0xdeb
let _Thai_thanthakhat : keysym = 0xdec
let _Thai_nikhahit : keysym = 0xded
let _Thai_leksun : keysym = 0xdf0
let _Thai_leknung : keysym = 0xdf1
let _Thai_leksong : keysym = 0xdf2
let _Thai_leksam : keysym = 0xdf3
let _Thai_leksi : keysym = 0xdf4
let _Thai_lekha : keysym = 0xdf5
let _Thai_lekhok : keysym = 0xdf6
let _Thai_lekchet : keysym = 0xdf7
let _Thai_lekpaet : keysym = 0xdf8
let _Thai_lekkao : keysym = 0xdf9
let _Hangul : keysym = 0xff31
let _Hangul_Start : keysym = 0xff32
let _Hangul_End : keysym = 0xff33
let _Hangul_Hanja : keysym = 0xff34
let _Hangul_Jamo : keysym = 0xff35
let _Hangul_Romaja : keysym = 0xff36
let _Hangul_Codeinput : keysym = 0xff37
let _Hangul_Jeonja : keysym = 0xff38
let _Hangul_Banja : keysym = 0xff39
let _Hangul_PreHanja : keysym = 0xff3a
let _Hangul_PostHanja : keysym = 0xff3b
let _Hangul_SingleCandidate : keysym = 0xff3c
let _Hangul_MultipleCandidate : keysym = 0xff3d
let _Hangul_PreviousCandidate : keysym = 0xff3e
let _Hangul_Special : keysym = 0xff3f
let _Hangul_switch : keysym = 0xff7e
let _Hangul_Kiyeog : keysym = 0xea1
let _Hangul_SsangKiyeog : keysym = 0xea2
let _Hangul_KiyeogSios : keysym = 0xea3
let _Hangul_Nieun : keysym = 0xea4
let _Hangul_NieunJieuj : keysym = 0xea5
let _Hangul_NieunHieuh : keysym = 0xea6
let _Hangul_Dikeud : keysym = 0xea7
let _Hangul_SsangDikeud : keysym = 0xea8
let _Hangul_Rieul : keysym = 0xea9
let _Hangul_RieulKiyeog : keysym = 0xeaa
let _Hangul_RieulMieum : keysym = 0xeab
let _Hangul_RieulPieub : keysym = 0xeac
let _Hangul_RieulSios : keysym = 0xead
let _Hangul_RieulTieut : keysym = 0xeae
let _Hangul_RieulPhieuf : keysym = 0xeaf
let _Hangul_RieulHieuh : keysym = 0xeb0
let _Hangul_Mieum : keysym = 0xeb1
let _Hangul_Pieub : keysym = 0xeb2
let _Hangul_SsangPieub : keysym = 0xeb3
let _Hangul_PieubSios : keysym = 0xeb4
let _Hangul_Sios : keysym = 0xeb5
let _Hangul_SsangSios : keysym = 0xeb6
let _Hangul_Ieung : keysym = 0xeb7
let _Hangul_Jieuj : keysym = 0xeb8
let _Hangul_SsangJieuj : keysym = 0xeb9
let _Hangul_Cieuc : keysym = 0xeba
let _Hangul_Khieuq : keysym = 0xebb
let _Hangul_Tieut : keysym = 0xebc
let _Hangul_Phieuf : keysym = 0xebd
let _Hangul_Hieuh : keysym = 0xebe
let _Hangul_A : keysym = 0xebf
let _Hangul_AE : keysym = 0xec0
let _Hangul_YA : keysym = 0xec1
let _Hangul_YAE : keysym = 0xec2
let _Hangul_EO : keysym = 0xec3
let _Hangul_E : keysym = 0xec4
let _Hangul_YEO : keysym = 0xec5
let _Hangul_YE : keysym = 0xec6
let _Hangul_O : keysym = 0xec7
let _Hangul_WA : keysym = 0xec8
let _Hangul_WAE : keysym = 0xec9
let _Hangul_OE : keysym = 0xeca
let _Hangul_YO : keysym = 0xecb
let _Hangul_U : keysym = 0xecc
let _Hangul_WEO : keysym = 0xecd
let _Hangul_WE : keysym = 0xece
let _Hangul_WI : keysym = 0xecf
let _Hangul_YU : keysym = 0xed0
let _Hangul_EU : keysym = 0xed1
let _Hangul_YI : keysym = 0xed2
let _Hangul_I : keysym = 0xed3
let _Hangul_J_Kiyeog : keysym = 0xed4
let _Hangul_J_SsangKiyeog : keysym = 0xed5
let _Hangul_J_KiyeogSios : keysym = 0xed6
let _Hangul_J_Nieun : keysym = 0xed7
let _Hangul_J_NieunJieuj : keysym = 0xed8
let _Hangul_J_NieunHieuh : keysym = 0xed9
let _Hangul_J_Dikeud : keysym = 0xeda
let _Hangul_J_Rieul : keysym = 0xedb
let _Hangul_J_RieulKiyeog : keysym = 0xedc
let _Hangul_J_RieulMieum : keysym = 0xedd
let _Hangul_J_RieulPieub : keysym = 0xede
let _Hangul_J_RieulSios : keysym = 0xedf
let _Hangul_J_RieulTieut : keysym = 0xee0
let _Hangul_J_RieulPhieuf : keysym = 0xee1
let _Hangul_J_RieulHieuh : keysym = 0xee2
let _Hangul_J_Mieum : keysym = 0xee3
let _Hangul_J_Pieub : keysym = 0xee4
let _Hangul_J_PieubSios : keysym = 0xee5
let _Hangul_J_Sios : keysym = 0xee6
let _Hangul_J_SsangSios : keysym = 0xee7
let _Hangul_J_Ieung : keysym = 0xee8
let _Hangul_J_Jieuj : keysym = 0xee9
let _Hangul_J_Cieuc : keysym = 0xeea
let _Hangul_J_Khieuq : keysym = 0xeeb
let _Hangul_J_Tieut : keysym = 0xeec
let _Hangul_J_Phieuf : keysym = 0xeed
let _Hangul_J_Hieuh : keysym = 0xeee
let _Hangul_RieulYeorinHieuh : keysym = 0xeef
let _Hangul_SunkyeongeumMieum : keysym = 0xef0
let _Hangul_SunkyeongeumPieub : keysym = 0xef1
let _Hangul_PanSios : keysym = 0xef2
let _Hangul_KkogjiDalrinIeung : keysym = 0xef3
let _Hangul_SunkyeongeumPhieuf : keysym = 0xef4
let _Hangul_YeorinHieuh : keysym = 0xef5
let _Hangul_AraeA : keysym = 0xef6
let _Hangul_AraeAE : keysym = 0xef7
let _Hangul_J_PanSios : keysym = 0xef8
let _Hangul_J_KkogjiDalrinIeung : keysym = 0xef9
let _Hangul_J_YeorinHieuh : keysym = 0xefa
let _Korean_Won : keysym = 0xeff
let _Armenian_ligature_ew : keysym = 0x1000587
let _Armenian_full_stop : keysym = 0x1000589
let _Armenian_verjaket : keysym = 0x1000589
let _Armenian_separation_mark : keysym = 0x100055d
let _Armenian_but : keysym = 0x100055d
let _Armenian_hyphen : keysym = 0x100058a
let _Armenian_yentamna : keysym = 0x100058a
let _Armenian_exclam : keysym = 0x100055c
let _Armenian_amanak : keysym = 0x100055c
let _Armenian_accent : keysym = 0x100055b
let _Armenian_shesht : keysym = 0x100055b
let _Armenian_question : keysym = 0x100055e
let _Armenian_paruyk : keysym = 0x100055e
let _Armenian_AYB : keysym = 0x1000531
let _Armenian_ayb : keysym = 0x1000561
let _Armenian_BEN : keysym = 0x1000532
let _Armenian_ben : keysym = 0x1000562
let _Armenian_GIM : keysym = 0x1000533
let _Armenian_gim : keysym = 0x1000563
let _Armenian_DA : keysym = 0x1000534
let _Armenian_da : keysym = 0x1000564
let _Armenian_YECH : keysym = 0x1000535
let _Armenian_yech : keysym = 0x1000565
let _Armenian_ZA : keysym = 0x1000536
let _Armenian_za : keysym = 0x1000566
let _Armenian_E : keysym = 0x1000537
let _Armenian_e : keysym = 0x1000567
let _Armenian_AT : keysym = 0x1000538
let _Armenian_at : keysym = 0x1000568
let _Armenian_TO : keysym = 0x1000539
let _Armenian_to : keysym = 0x1000569
let _Armenian_ZHE : keysym = 0x100053a
let _Armenian_zhe : keysym = 0x100056a
let _Armenian_INI : keysym = 0x100053b
let _Armenian_ini : keysym = 0x100056b
let _Armenian_LYUN : keysym = 0x100053c
let _Armenian_lyun : keysym = 0x100056c
let _Armenian_KHE : keysym = 0x100053d
let _Armenian_khe : keysym = 0x100056d
let _Armenian_TSA : keysym = 0x100053e
let _Armenian_tsa : keysym = 0x100056e
let _Armenian_KEN : keysym = 0x100053f
let _Armenian_ken : keysym = 0x100056f
let _Armenian_HO : keysym = 0x1000540
let _Armenian_ho : keysym = 0x1000570
let _Armenian_DZA : keysym = 0x1000541
let _Armenian_dza : keysym = 0x1000571
let _Armenian_GHAT : keysym = 0x1000542
let _Armenian_ghat : keysym = 0x1000572
let _Armenian_TCHE : keysym = 0x1000543
let _Armenian_tche : keysym = 0x1000573
let _Armenian_MEN : keysym = 0x1000544
let _Armenian_men : keysym = 0x1000574
let _Armenian_HI : keysym = 0x1000545
let _Armenian_hi : keysym = 0x1000575
let _Armenian_NU : keysym = 0x1000546
let _Armenian_nu : keysym = 0x1000576
let _Armenian_SHA : keysym = 0x1000547
let _Armenian_sha : keysym = 0x1000577
let _Armenian_VO : keysym = 0x1000548
let _Armenian_vo : keysym = 0x1000578
let _Armenian_CHA : keysym = 0x1000549
let _Armenian_cha : keysym = 0x1000579
let _Armenian_PE : keysym = 0x100054a
let _Armenian_pe : keysym = 0x100057a
let _Armenian_JE : keysym = 0x100054b
let _Armenian_je : keysym = 0x100057b
let _Armenian_RA : keysym = 0x100054c
let _Armenian_ra : keysym = 0x100057c
let _Armenian_SE : keysym = 0x100054d
let _Armenian_se : keysym = 0x100057d
let _Armenian_VEV : keysym = 0x100054e
let _Armenian_vev : keysym = 0x100057e
let _Armenian_TYUN : keysym = 0x100054f
let _Armenian_tyun : keysym = 0x100057f
let _Armenian_RE : keysym = 0x1000550
let _Armenian_re : keysym = 0x1000580
let _Armenian_TSO : keysym = 0x1000551
let _Armenian_tso : keysym = 0x1000581
let _Armenian_VYUN : keysym = 0x1000552
let _Armenian_vyun : keysym = 0x1000582
let _Armenian_PYUR : keysym = 0x1000553
let _Armenian_pyur : keysym = 0x1000583
let _Armenian_KE : keysym = 0x1000554
let _Armenian_ke : keysym = 0x1000584
let _Armenian_O : keysym = 0x1000555
let _Armenian_o : keysym = 0x1000585
let _Armenian_FE : keysym = 0x1000556
let _Armenian_fe : keysym = 0x1000586
let _Armenian_apostrophe : keysym = 0x100055a
let _Georgian_an : keysym = 0x10010d0
let _Georgian_ban : keysym = 0x10010d1
let _Georgian_gan : keysym = 0x10010d2
let _Georgian_don : keysym = 0x10010d3
let _Georgian_en : keysym = 0x10010d4
let _Georgian_vin : keysym = 0x10010d5
let _Georgian_zen : keysym = 0x10010d6
let _Georgian_tan : keysym = 0x10010d7
let _Georgian_in : keysym = 0x10010d8
let _Georgian_kan : keysym = 0x10010d9
let _Georgian_las : keysym = 0x10010da
let _Georgian_man : keysym = 0x10010db
let _Georgian_nar : keysym = 0x10010dc
let _Georgian_on : keysym = 0x10010dd
let _Georgian_par : keysym = 0x10010de
let _Georgian_zhar : keysym = 0x10010df
let _Georgian_rae : keysym = 0x10010e0
let _Georgian_san : keysym = 0x10010e1
let _Georgian_tar : keysym = 0x10010e2
let _Georgian_un : keysym = 0x10010e3
let _Georgian_phar : keysym = 0x10010e4
let _Georgian_khar : keysym = 0x10010e5
let _Georgian_ghan : keysym = 0x10010e6
let _Georgian_qar : keysym = 0x10010e7
let _Georgian_shin : keysym = 0x10010e8
let _Georgian_chin : keysym = 0x10010e9
let _Georgian_can : keysym = 0x10010ea
let _Georgian_jil : keysym = 0x10010eb
let _Georgian_cil : keysym = 0x10010ec
let _Georgian_char : keysym = 0x10010ed
let _Georgian_xan : keysym = 0x10010ee
let _Georgian_jhan : keysym = 0x10010ef
let _Georgian_hae : keysym = 0x10010f0
let _Georgian_he : keysym = 0x10010f1
let _Georgian_hie : keysym = 0x10010f2
let _Georgian_we : keysym = 0x10010f3
let _Georgian_har : keysym = 0x10010f4
let _Georgian_hoe : keysym = 0x10010f5
let _Georgian_fi : keysym = 0x10010f6
let _Xabovedot : keysym = 0x1001e8a
let _Ibreve : keysym = 0x100012c
let _Zstroke : keysym = 0x10001b5
let _Gcaron : keysym = 0x10001e6
let _Ocaron : keysym = 0x10001d1
let _Obarred : keysym = 0x100019f
let _xabovedot : keysym = 0x1001e8b
let _ibreve : keysym = 0x100012d
let _zstroke : keysym = 0x10001b6
let _gcaron : keysym = 0x10001e7
let _ocaron : keysym = 0x10001d2
let _obarred : keysym = 0x1000275
let _SCHWA : keysym = 0x100018f
let _schwa : keysym = 0x1000259
let _EZH : keysym = 0x10001b7
let _ezh : keysym = 0x1000292
let _Lbelowdot : keysym = 0x1001e36
let _lbelowdot : keysym = 0x1001e37
let _Abelowdot : keysym = 0x1001ea0
let _abelowdot : keysym = 0x1001ea1
let _Ahook : keysym = 0x1001ea2
let _ahook : keysym = 0x1001ea3
let _Acircumflexacute : keysym = 0x1001ea4
let _acircumflexacute : keysym = 0x1001ea5
let _Acircumflexgrave : keysym = 0x1001ea6
let _acircumflexgrave : keysym = 0x1001ea7
let _Acircumflexhook : keysym = 0x1001ea8
let _acircumflexhook : keysym = 0x1001ea9
let _Acircumflextilde : keysym = 0x1001eaa
let _acircumflextilde : keysym = 0x1001eab
let _Acircumflexbelowdot : keysym = 0x1001eac
let _acircumflexbelowdot : keysym = 0x1001ead
let _Abreveacute : keysym = 0x1001eae
let _abreveacute : keysym = 0x1001eaf
let _Abrevegrave : keysym = 0x1001eb0
let _abrevegrave : keysym = 0x1001eb1
let _Abrevehook : keysym = 0x1001eb2
let _abrevehook : keysym = 0x1001eb3
let _Abrevetilde : keysym = 0x1001eb4
let _abrevetilde : keysym = 0x1001eb5
let _Abrevebelowdot : keysym = 0x1001eb6
let _abrevebelowdot : keysym = 0x1001eb7
let _Ebelowdot : keysym = 0x1001eb8
let _ebelowdot : keysym = 0x1001eb9
let _Ehook : keysym = 0x1001eba
let _ehook : keysym = 0x1001ebb
let _Etilde : keysym = 0x1001ebc
let _etilde : keysym = 0x1001ebd
let _Ecircumflexacute : keysym = 0x1001ebe
let _ecircumflexacute : keysym = 0x1001ebf
let _Ecircumflexgrave : keysym = 0x1001ec0
let _ecircumflexgrave : keysym = 0x1001ec1
let _Ecircumflexhook : keysym = 0x1001ec2
let _ecircumflexhook : keysym = 0x1001ec3
let _Ecircumflextilde : keysym = 0x1001ec4
let _ecircumflextilde : keysym = 0x1001ec5
let _Ecircumflexbelowdot : keysym = 0x1001ec6
let _ecircumflexbelowdot : keysym = 0x1001ec7
let _Ihook : keysym = 0x1001ec8
let _ihook : keysym = 0x1001ec9
let _Ibelowdot : keysym = 0x1001eca
let _ibelowdot : keysym = 0x1001ecb
let _Obelowdot : keysym = 0x1001ecc
let _obelowdot : keysym = 0x1001ecd
let _Ohook : keysym = 0x1001ece
let _ohook : keysym = 0x1001ecf
let _Ocircumflexacute : keysym = 0x1001ed0
let _ocircumflexacute : keysym = 0x1001ed1
let _Ocircumflexgrave : keysym = 0x1001ed2
let _ocircumflexgrave : keysym = 0x1001ed3
let _Ocircumflexhook : keysym = 0x1001ed4
let _ocircumflexhook : keysym = 0x1001ed5
let _Ocircumflextilde : keysym = 0x1001ed6
let _ocircumflextilde : keysym = 0x1001ed7
let _Ocircumflexbelowdot : keysym = 0x1001ed8
let _ocircumflexbelowdot : keysym = 0x1001ed9
let _Ohornacute : keysym = 0x1001eda
let _ohornacute : keysym = 0x1001edb
let _Ohorngrave : keysym = 0x1001edc
let _ohorngrave : keysym = 0x1001edd
let _Ohornhook : keysym = 0x1001ede
let _ohornhook : keysym = 0x1001edf
let _Ohorntilde : keysym = 0x1001ee0
let _ohorntilde : keysym = 0x1001ee1
let _Ohornbelowdot : keysym = 0x1001ee2
let _ohornbelowdot : keysym = 0x1001ee3
let _Ubelowdot : keysym = 0x1001ee4
let _ubelowdot : keysym = 0x1001ee5
let _Uhook : keysym = 0x1001ee6
let _uhook : keysym = 0x1001ee7
let _Uhornacute : keysym = 0x1001ee8
let _uhornacute : keysym = 0x1001ee9
let _Uhorngrave : keysym = 0x1001eea
let _uhorngrave : keysym = 0x1001eeb
let _Uhornhook : keysym = 0x1001eec
let _uhornhook : keysym = 0x1001eed
let _Uhorntilde : keysym = 0x1001eee
let _uhorntilde : keysym = 0x1001eef
let _Uhornbelowdot : keysym = 0x1001ef0
let _uhornbelowdot : keysym = 0x1001ef1
let _Ybelowdot : keysym = 0x1001ef4
let _ybelowdot : keysym = 0x1001ef5
let _Yhook : keysym = 0x1001ef6
let _yhook : keysym = 0x1001ef7
let _Ytilde : keysym = 0x1001ef8
let _ytilde : keysym = 0x1001ef9
let _Ohorn : keysym = 0x10001a0
let _ohorn : keysym = 0x10001a1
let _Uhorn : keysym = 0x10001af
let _uhorn : keysym = 0x10001b0
let _EcuSign : keysym = 0x10020a0
let _ColonSign : keysym = 0x10020a1
let _CruzeiroSign : keysym = 0x10020a2
let _FFrancSign : keysym = 0x10020a3
let _LiraSign : keysym = 0x10020a4
let _MillSign : keysym = 0x10020a5
let _NairaSign : keysym = 0x10020a6
let _PesetaSign : keysym = 0x10020a7
let _RupeeSign : keysym = 0x10020a8
let _WonSign : keysym = 0x10020a9
let _NewSheqelSign : keysym = 0x10020aa
let _DongSign : keysym = 0x10020ab
let _EuroSign : keysym = 0x20ac
let _zerosuperior : keysym = 0x1002070
let _foursuperior : keysym = 0x1002074
let _fivesuperior : keysym = 0x1002075
let _sixsuperior : keysym = 0x1002076
let _sevensuperior : keysym = 0x1002077
let _eightsuperior : keysym = 0x1002078
let _ninesuperior : keysym = 0x1002079
let _zerosubscript : keysym = 0x1002080
let _onesubscript : keysym = 0x1002081
let _twosubscript : keysym = 0x1002082
let _threesubscript : keysym = 0x1002083
let _foursubscript : keysym = 0x1002084
let _fivesubscript : keysym = 0x1002085
let _sixsubscript : keysym = 0x1002086
let _sevensubscript : keysym = 0x1002087
let _eightsubscript : keysym = 0x1002088
let _ninesubscript : keysym = 0x1002089
let _partdifferential : keysym = 0x1002202
let _emptyset : keysym = 0x1002205
let _elementof : keysym = 0x1002208
let _notelementof : keysym = 0x1002209
let _containsas : keysym = 0x100220b
let _squareroot : keysym = 0x100221a
let _cuberoot : keysym = 0x100221b
let _fourthroot : keysym = 0x100221c
let _dintegral : keysym = 0x100222c
let _tintegral : keysym = 0x100222d
let _because : keysym = 0x1002235
let _approxeq : keysym = 0x1002248
let _notapproxeq : keysym = 0x1002247
let _notidentical : keysym = 0x1002262
let _stricteq : keysym = 0x1002263
let _braille_dot_1 : keysym = 0xfff1
let _braille_dot_2 : keysym = 0xfff2
let _braille_dot_3 : keysym = 0xfff3
let _braille_dot_4 : keysym = 0xfff4
let _braille_dot_5 : keysym = 0xfff5
let _braille_dot_6 : keysym = 0xfff6
let _braille_dot_7 : keysym = 0xfff7
let _braille_dot_8 : keysym = 0xfff8
let _braille_dot_9 : keysym = 0xfff9
let _braille_dot_10 : keysym = 0xfffa
let _braille_blank : keysym = 0x1002800
let _braille_dots_1 : keysym = 0x1002801
let _braille_dots_2 : keysym = 0x1002802
let _braille_dots_12 : keysym = 0x1002803
let _braille_dots_3 : keysym = 0x1002804
let _braille_dots_13 : keysym = 0x1002805
let _braille_dots_23 : keysym = 0x1002806
let _braille_dots_123 : keysym = 0x1002807
let _braille_dots_4 : keysym = 0x1002808
let _braille_dots_14 : keysym = 0x1002809
let _braille_dots_24 : keysym = 0x100280a
let _braille_dots_124 : keysym = 0x100280b
let _braille_dots_34 : keysym = 0x100280c
let _braille_dots_134 : keysym = 0x100280d
let _braille_dots_234 : keysym = 0x100280e
let _braille_dots_1234 : keysym = 0x100280f
let _braille_dots_5 : keysym = 0x1002810
let _braille_dots_15 : keysym = 0x1002811
let _braille_dots_25 : keysym = 0x1002812
let _braille_dots_125 : keysym = 0x1002813
let _braille_dots_35 : keysym = 0x1002814
let _braille_dots_135 : keysym = 0x1002815
let _braille_dots_235 : keysym = 0x1002816
let _braille_dots_1235 : keysym = 0x1002817
let _braille_dots_45 : keysym = 0x1002818
let _braille_dots_145 : keysym = 0x1002819
let _braille_dots_245 : keysym = 0x100281a
let _braille_dots_1245 : keysym = 0x100281b
let _braille_dots_345 : keysym = 0x100281c
let _braille_dots_1345 : keysym = 0x100281d
let _braille_dots_2345 : keysym = 0x100281e
let _braille_dots_12345 : keysym = 0x100281f
let _braille_dots_6 : keysym = 0x1002820
let _braille_dots_16 : keysym = 0x1002821
let _braille_dots_26 : keysym = 0x1002822
let _braille_dots_126 : keysym = 0x1002823
let _braille_dots_36 : keysym = 0x1002824
let _braille_dots_136 : keysym = 0x1002825
let _braille_dots_236 : keysym = 0x1002826
let _braille_dots_1236 : keysym = 0x1002827
let _braille_dots_46 : keysym = 0x1002828
let _braille_dots_146 : keysym = 0x1002829
let _braille_dots_246 : keysym = 0x100282a
let _braille_dots_1246 : keysym = 0x100282b
let _braille_dots_346 : keysym = 0x100282c
let _braille_dots_1346 : keysym = 0x100282d
let _braille_dots_2346 : keysym = 0x100282e
let _braille_dots_12346 : keysym = 0x100282f
let _braille_dots_56 : keysym = 0x1002830
let _braille_dots_156 : keysym = 0x1002831
let _braille_dots_256 : keysym = 0x1002832
let _braille_dots_1256 : keysym = 0x1002833
let _braille_dots_356 : keysym = 0x1002834
let _braille_dots_1356 : keysym = 0x1002835
let _braille_dots_2356 : keysym = 0x1002836
let _braille_dots_12356 : keysym = 0x1002837
let _braille_dots_456 : keysym = 0x1002838
let _braille_dots_1456 : keysym = 0x1002839
let _braille_dots_2456 : keysym = 0x100283a
let _braille_dots_12456 : keysym = 0x100283b
let _braille_dots_3456 : keysym = 0x100283c
let _braille_dots_13456 : keysym = 0x100283d
let _braille_dots_23456 : keysym = 0x100283e
let _braille_dots_123456 : keysym = 0x100283f
let _braille_dots_7 : keysym = 0x1002840
let _braille_dots_17 : keysym = 0x1002841
let _braille_dots_27 : keysym = 0x1002842
let _braille_dots_127 : keysym = 0x1002843
let _braille_dots_37 : keysym = 0x1002844
let _braille_dots_137 : keysym = 0x1002845
let _braille_dots_237 : keysym = 0x1002846
let _braille_dots_1237 : keysym = 0x1002847
let _braille_dots_47 : keysym = 0x1002848
let _braille_dots_147 : keysym = 0x1002849
let _braille_dots_247 : keysym = 0x100284a
let _braille_dots_1247 : keysym = 0x100284b
let _braille_dots_347 : keysym = 0x100284c
let _braille_dots_1347 : keysym = 0x100284d
let _braille_dots_2347 : keysym = 0x100284e
let _braille_dots_12347 : keysym = 0x100284f
let _braille_dots_57 : keysym = 0x1002850
let _braille_dots_157 : keysym = 0x1002851
let _braille_dots_257 : keysym = 0x1002852
let _braille_dots_1257 : keysym = 0x1002853
let _braille_dots_357 : keysym = 0x1002854
let _braille_dots_1357 : keysym = 0x1002855
let _braille_dots_2357 : keysym = 0x1002856
let _braille_dots_12357 : keysym = 0x1002857
let _braille_dots_457 : keysym = 0x1002858
let _braille_dots_1457 : keysym = 0x1002859
let _braille_dots_2457 : keysym = 0x100285a
let _braille_dots_12457 : keysym = 0x100285b
let _braille_dots_3457 : keysym = 0x100285c
let _braille_dots_13457 : keysym = 0x100285d
let _braille_dots_23457 : keysym = 0x100285e
let _braille_dots_123457 : keysym = 0x100285f
let _braille_dots_67 : keysym = 0x1002860
let _braille_dots_167 : keysym = 0x1002861
let _braille_dots_267 : keysym = 0x1002862
let _braille_dots_1267 : keysym = 0x1002863
let _braille_dots_367 : keysym = 0x1002864
let _braille_dots_1367 : keysym = 0x1002865
let _braille_dots_2367 : keysym = 0x1002866
let _braille_dots_12367 : keysym = 0x1002867
let _braille_dots_467 : keysym = 0x1002868
let _braille_dots_1467 : keysym = 0x1002869
let _braille_dots_2467 : keysym = 0x100286a
let _braille_dots_12467 : keysym = 0x100286b
let _braille_dots_3467 : keysym = 0x100286c
let _braille_dots_13467 : keysym = 0x100286d
let _braille_dots_23467 : keysym = 0x100286e
let _braille_dots_123467 : keysym = 0x100286f
let _braille_dots_567 : keysym = 0x1002870
let _braille_dots_1567 : keysym = 0x1002871
let _braille_dots_2567 : keysym = 0x1002872
let _braille_dots_12567 : keysym = 0x1002873
let _braille_dots_3567 : keysym = 0x1002874
let _braille_dots_13567 : keysym = 0x1002875
let _braille_dots_23567 : keysym = 0x1002876
let _braille_dots_123567 : keysym = 0x1002877
let _braille_dots_4567 : keysym = 0x1002878
let _braille_dots_14567 : keysym = 0x1002879
let _braille_dots_24567 : keysym = 0x100287a
let _braille_dots_124567 : keysym = 0x100287b
let _braille_dots_34567 : keysym = 0x100287c
let _braille_dots_134567 : keysym = 0x100287d
let _braille_dots_234567 : keysym = 0x100287e
let _braille_dots_1234567 : keysym = 0x100287f
let _braille_dots_8 : keysym = 0x1002880
let _braille_dots_18 : keysym = 0x1002881
let _braille_dots_28 : keysym = 0x1002882
let _braille_dots_128 : keysym = 0x1002883
let _braille_dots_38 : keysym = 0x1002884
let _braille_dots_138 : keysym = 0x1002885
let _braille_dots_238 : keysym = 0x1002886
let _braille_dots_1238 : keysym = 0x1002887
let _braille_dots_48 : keysym = 0x1002888
let _braille_dots_148 : keysym = 0x1002889
let _braille_dots_248 : keysym = 0x100288a
let _braille_dots_1248 : keysym = 0x100288b
let _braille_dots_348 : keysym = 0x100288c
let _braille_dots_1348 : keysym = 0x100288d
let _braille_dots_2348 : keysym = 0x100288e
let _braille_dots_12348 : keysym = 0x100288f
let _braille_dots_58 : keysym = 0x1002890
let _braille_dots_158 : keysym = 0x1002891
let _braille_dots_258 : keysym = 0x1002892
let _braille_dots_1258 : keysym = 0x1002893
let _braille_dots_358 : keysym = 0x1002894
let _braille_dots_1358 : keysym = 0x1002895
let _braille_dots_2358 : keysym = 0x1002896
let _braille_dots_12358 : keysym = 0x1002897
let _braille_dots_458 : keysym = 0x1002898
let _braille_dots_1458 : keysym = 0x1002899
let _braille_dots_2458 : keysym = 0x100289a
let _braille_dots_12458 : keysym = 0x100289b
let _braille_dots_3458 : keysym = 0x100289c
let _braille_dots_13458 : keysym = 0x100289d
let _braille_dots_23458 : keysym = 0x100289e
let _braille_dots_123458 : keysym = 0x100289f
let _braille_dots_68 : keysym = 0x10028a0
let _braille_dots_168 : keysym = 0x10028a1
let _braille_dots_268 : keysym = 0x10028a2
let _braille_dots_1268 : keysym = 0x10028a3
let _braille_dots_368 : keysym = 0x10028a4
let _braille_dots_1368 : keysym = 0x10028a5
let _braille_dots_2368 : keysym = 0x10028a6
let _braille_dots_12368 : keysym = 0x10028a7
let _braille_dots_468 : keysym = 0x10028a8
let _braille_dots_1468 : keysym = 0x10028a9
let _braille_dots_2468 : keysym = 0x10028aa
let _braille_dots_12468 : keysym = 0x10028ab
let _braille_dots_3468 : keysym = 0x10028ac
let _braille_dots_13468 : keysym = 0x10028ad
let _braille_dots_23468 : keysym = 0x10028ae
let _braille_dots_123468 : keysym = 0x10028af
let _braille_dots_568 : keysym = 0x10028b0
let _braille_dots_1568 : keysym = 0x10028b1
let _braille_dots_2568 : keysym = 0x10028b2
let _braille_dots_12568 : keysym = 0x10028b3
let _braille_dots_3568 : keysym = 0x10028b4
let _braille_dots_13568 : keysym = 0x10028b5
let _braille_dots_23568 : keysym = 0x10028b6
let _braille_dots_123568 : keysym = 0x10028b7
let _braille_dots_4568 : keysym = 0x10028b8
let _braille_dots_14568 : keysym = 0x10028b9
let _braille_dots_24568 : keysym = 0x10028ba
let _braille_dots_124568 : keysym = 0x10028bb
let _braille_dots_34568 : keysym = 0x10028bc
let _braille_dots_134568 : keysym = 0x10028bd
let _braille_dots_234568 : keysym = 0x10028be
let _braille_dots_1234568 : keysym = 0x10028bf
let _braille_dots_78 : keysym = 0x10028c0
let _braille_dots_178 : keysym = 0x10028c1
let _braille_dots_278 : keysym = 0x10028c2
let _braille_dots_1278 : keysym = 0x10028c3
let _braille_dots_378 : keysym = 0x10028c4
let _braille_dots_1378 : keysym = 0x10028c5
let _braille_dots_2378 : keysym = 0x10028c6
let _braille_dots_12378 : keysym = 0x10028c7
let _braille_dots_478 : keysym = 0x10028c8
let _braille_dots_1478 : keysym = 0x10028c9
let _braille_dots_2478 : keysym = 0x10028ca
let _braille_dots_12478 : keysym = 0x10028cb
let _braille_dots_3478 : keysym = 0x10028cc
let _braille_dots_13478 : keysym = 0x10028cd
let _braille_dots_23478 : keysym = 0x10028ce
let _braille_dots_123478 : keysym = 0x10028cf
let _braille_dots_578 : keysym = 0x10028d0
let _braille_dots_1578 : keysym = 0x10028d1
let _braille_dots_2578 : keysym = 0x10028d2
let _braille_dots_12578 : keysym = 0x10028d3
let _braille_dots_3578 : keysym = 0x10028d4
let _braille_dots_13578 : keysym = 0x10028d5
let _braille_dots_23578 : keysym = 0x10028d6
let _braille_dots_123578 : keysym = 0x10028d7
let _braille_dots_4578 : keysym = 0x10028d8
let _braille_dots_14578 : keysym = 0x10028d9
let _braille_dots_24578 : keysym = 0x10028da
let _braille_dots_124578 : keysym = 0x10028db
let _braille_dots_34578 : keysym = 0x10028dc
let _braille_dots_134578 : keysym = 0x10028dd
let _braille_dots_234578 : keysym = 0x10028de
let _braille_dots_1234578 : keysym = 0x10028df
let _braille_dots_678 : keysym = 0x10028e0
let _braille_dots_1678 : keysym = 0x10028e1
let _braille_dots_2678 : keysym = 0x10028e2
let _braille_dots_12678 : keysym = 0x10028e3
let _braille_dots_3678 : keysym = 0x10028e4
let _braille_dots_13678 : keysym = 0x10028e5
let _braille_dots_23678 : keysym = 0x10028e6
let _braille_dots_123678 : keysym = 0x10028e7
let _braille_dots_4678 : keysym = 0x10028e8
let _braille_dots_14678 : keysym = 0x10028e9
let _braille_dots_24678 : keysym = 0x10028ea
let _braille_dots_124678 : keysym = 0x10028eb
let _braille_dots_34678 : keysym = 0x10028ec
let _braille_dots_134678 : keysym = 0x10028ed
let _braille_dots_234678 : keysym = 0x10028ee
let _braille_dots_1234678 : keysym = 0x10028ef
let _braille_dots_5678 : keysym = 0x10028f0
let _braille_dots_15678 : keysym = 0x10028f1
let _braille_dots_25678 : keysym = 0x10028f2
let _braille_dots_125678 : keysym = 0x10028f3
let _braille_dots_35678 : keysym = 0x10028f4
let _braille_dots_135678 : keysym = 0x10028f5
let _braille_dots_235678 : keysym = 0x10028f6
let _braille_dots_1235678 : keysym = 0x10028f7
let _braille_dots_45678 : keysym = 0x10028f8
let _braille_dots_145678 : keysym = 0x10028f9
let _braille_dots_245678 : keysym = 0x10028fa
let _braille_dots_1245678 : keysym = 0x10028fb
let _braille_dots_345678 : keysym = 0x10028fc
let _braille_dots_1345678 : keysym = 0x10028fd
let _braille_dots_2345678 : keysym = 0x10028fe
let _braille_dots_12345678 : keysym = 0x10028ff
let _Sinh_ng : keysym = 0x1000d82
let _Sinh_h2 : keysym = 0x1000d83
let _Sinh_a : keysym = 0x1000d85
let _Sinh_aa : keysym = 0x1000d86
let _Sinh_ae : keysym = 0x1000d87
let _Sinh_aee : keysym = 0x1000d88
let _Sinh_i : keysym = 0x1000d89
let _Sinh_ii : keysym = 0x1000d8a
let _Sinh_u : keysym = 0x1000d8b
let _Sinh_uu : keysym = 0x1000d8c
let _Sinh_ri : keysym = 0x1000d8d
let _Sinh_rii : keysym = 0x1000d8e
let _Sinh_lu : keysym = 0x1000d8f
let _Sinh_luu : keysym = 0x1000d90
let _Sinh_e : keysym = 0x1000d91
let _Sinh_ee : keysym = 0x1000d92
let _Sinh_ai : keysym = 0x1000d93
let _Sinh_o : keysym = 0x1000d94
let _Sinh_oo : keysym = 0x1000d95
let _Sinh_au : keysym = 0x1000d96
let _Sinh_ka : keysym = 0x1000d9a
let _Sinh_kha : keysym = 0x1000d9b
let _Sinh_ga : keysym = 0x1000d9c
let _Sinh_gha : keysym = 0x1000d9d
let _Sinh_ng2 : keysym = 0x1000d9e
let _Sinh_nga : keysym = 0x1000d9f
let _Sinh_ca : keysym = 0x1000da0
let _Sinh_cha : keysym = 0x1000da1
let _Sinh_ja : keysym = 0x1000da2
let _Sinh_jha : keysym = 0x1000da3
let _Sinh_nya : keysym = 0x1000da4
let _Sinh_jnya : keysym = 0x1000da5
let _Sinh_nja : keysym = 0x1000da6
let _Sinh_tta : keysym = 0x1000da7
let _Sinh_ttha : keysym = 0x1000da8
let _Sinh_dda : keysym = 0x1000da9
let _Sinh_ddha : keysym = 0x1000daa
let _Sinh_nna : keysym = 0x1000dab
let _Sinh_ndda : keysym = 0x1000dac
let _Sinh_tha : keysym = 0x1000dad
let _Sinh_thha : keysym = 0x1000dae
let _Sinh_dha : keysym = 0x1000daf
let _Sinh_dhha : keysym = 0x1000db0
let _Sinh_na : keysym = 0x1000db1
let _Sinh_ndha : keysym = 0x1000db3
let _Sinh_pa : keysym = 0x1000db4
let _Sinh_pha : keysym = 0x1000db5
let _Sinh_ba : keysym = 0x1000db6
let _Sinh_bha : keysym = 0x1000db7
let _Sinh_ma : keysym = 0x1000db8
let _Sinh_mba : keysym = 0x1000db9
let _Sinh_ya : keysym = 0x1000dba
let _Sinh_ra : keysym = 0x1000dbb
let _Sinh_la : keysym = 0x1000dbd
let _Sinh_va : keysym = 0x1000dc0
let _Sinh_sha : keysym = 0x1000dc1
let _Sinh_ssha : keysym = 0x1000dc2
let _Sinh_sa : keysym = 0x1000dc3
let _Sinh_ha : keysym = 0x1000dc4
let _Sinh_lla : keysym = 0x1000dc5
let _Sinh_fa : keysym = 0x1000dc6
let _Sinh_al : keysym = 0x1000dca
let _Sinh_aa2 : keysym = 0x1000dcf
let _Sinh_ae2 : keysym = 0x1000dd0
let _Sinh_aee2 : keysym = 0x1000dd1
let _Sinh_i2 : keysym = 0x1000dd2
let _Sinh_ii2 : keysym = 0x1000dd3
let _Sinh_u2 : keysym = 0x1000dd4
let _Sinh_uu2 : keysym = 0x1000dd6
let _Sinh_ru2 : keysym = 0x1000dd8
let _Sinh_e2 : keysym = 0x1000dd9
let _Sinh_ee2 : keysym = 0x1000dda
let _Sinh_ai2 : keysym = 0x1000ddb
let _Sinh_o2 : keysym = 0x1000ddc
let _Sinh_oo2 : keysym = 0x1000ddd
let _Sinh_au2 : keysym = 0x1000dde
let _Sinh_lu2 : keysym = 0x1000ddf
let _Sinh_ruu2 : keysym = 0x1000df2
let _Sinh_luu2 : keysym = 0x1000df3
let _Sinh_kunddaliya : keysym = 0x1000df4
let _ModeLock : keysym = 0x1008ff01
let _MonBrightnessUp : keysym = 0x1008ff02
let _MonBrightnessDown : keysym = 0x1008ff03
let _KbdLightOnOff : keysym = 0x1008ff04
let _KbdBrightnessUp : keysym = 0x1008ff05
let _KbdBrightnessDown : keysym = 0x1008ff06
let _Standby : keysym = 0x1008ff10
let _AudioLowerVolume : keysym = 0x1008ff11
let _AudioMute : keysym = 0x1008ff12
let _AudioRaiseVolume : keysym = 0x1008ff13
let _AudioPlay : keysym = 0x1008ff14
let _AudioStop : keysym = 0x1008ff15
let _AudioPrev : keysym = 0x1008ff16
let _AudioNext : keysym = 0x1008ff17
let _HomePage : keysym = 0x1008ff18
let _Mail : keysym = 0x1008ff19
let _Start : keysym = 0x1008ff1a
let _Search : keysym = 0x1008ff1b
let _AudioRecord : keysym = 0x1008ff1c
let _Calculator : keysym = 0x1008ff1d
let _Memo : keysym = 0x1008ff1e
let _ToDoList : keysym = 0x1008ff1f
let _Calendar : keysym = 0x1008ff20
let _PowerDown : keysym = 0x1008ff21
let _ContrastAdjust : keysym = 0x1008ff22
let _RockerUp : keysym = 0x1008ff23
let _RockerDown : keysym = 0x1008ff24
let _RockerEnter : keysym = 0x1008ff25
let _Back : keysym = 0x1008ff26
let _Forward : keysym = 0x1008ff27
let _Stop : keysym = 0x1008ff28
let _Refresh : keysym = 0x1008ff29
let _PowerOff : keysym = 0x1008ff2a
let _WakeUp : keysym = 0x1008ff2b
let _Eject : keysym = 0x1008ff2c
let _ScreenSaver : keysym = 0x1008ff2d
let _WWW : keysym = 0x1008ff2e
let _Sleep : keysym = 0x1008ff2f
let _Favorites : keysym = 0x1008ff30
let _AudioPause : keysym = 0x1008ff31
let _AudioMedia : keysym = 0x1008ff32
let _MyComputer : keysym = 0x1008ff33
let _VendorHome : keysym = 0x1008ff34
let _LightBulb : keysym = 0x1008ff35
let _Shop : keysym = 0x1008ff36
let _History : keysym = 0x1008ff37
let _OpenURL : keysym = 0x1008ff38
let _AddFavorite : keysym = 0x1008ff39
let _HotLinks : keysym = 0x1008ff3a
let _BrightnessAdjust : keysym = 0x1008ff3b
let _Finance : keysym = 0x1008ff3c
let _Community : keysym = 0x1008ff3d
let _AudioRewind : keysym = 0x1008ff3e
let _BackForward : keysym = 0x1008ff3f
let _Launch0 : keysym = 0x1008ff40
let _Launch1 : keysym = 0x1008ff41
let _Launch2 : keysym = 0x1008ff42
let _Launch3 : keysym = 0x1008ff43
let _Launch4 : keysym = 0x1008ff44
let _Launch5 : keysym = 0x1008ff45
let _Launch6 : keysym = 0x1008ff46
let _Launch7 : keysym = 0x1008ff47
let _Launch8 : keysym = 0x1008ff48
let _Launch9 : keysym = 0x1008ff49
let _LaunchA : keysym = 0x1008ff4a
let _LaunchB : keysym = 0x1008ff4b
let _LaunchC : keysym = 0x1008ff4c
let _LaunchD : keysym = 0x1008ff4d
let _LaunchE : keysym = 0x1008ff4e
let _LaunchF : keysym = 0x1008ff4f
let _ApplicationLeft : keysym = 0x1008ff50
let _ApplicationRight : keysym = 0x1008ff51
let _Book : keysym = 0x1008ff52
let _CD : keysym = 0x1008ff53
let _WindowClear : keysym = 0x1008ff55
let _Close : keysym = 0x1008ff56
let _Copy : keysym = 0x1008ff57
let _Cut : keysym = 0x1008ff58
let _Display : keysym = 0x1008ff59
let _DOS : keysym = 0x1008ff5a
let _Documents : keysym = 0x1008ff5b
let _Excel : keysym = 0x1008ff5c
let _Explorer : keysym = 0x1008ff5d
let _Game : keysym = 0x1008ff5e
let _Go : keysym = 0x1008ff5f
let _iTouch : keysym = 0x1008ff60
let _LogOff : keysym = 0x1008ff61
let _Market : keysym = 0x1008ff62
let _Meeting : keysym = 0x1008ff63
let _MenuKB : keysym = 0x1008ff65
let _MenuPB : keysym = 0x1008ff66
let _MySites : keysym = 0x1008ff67
let _New : keysym = 0x1008ff68
let _News : keysym = 0x1008ff69
let _OfficeHome : keysym = 0x1008ff6a
let _Open : keysym = 0x1008ff6b
let _Option : keysym = 0x1008ff6c
let _Paste : keysym = 0x1008ff6d
let _Phone : keysym = 0x1008ff6e
let _Reply : keysym = 0x1008ff72
let _Reload : keysym = 0x1008ff73
let _RotateWindows : keysym = 0x1008ff74
let _RotationPB : keysym = 0x1008ff75
let _RotationKB : keysym = 0x1008ff76
let _Save : keysym = 0x1008ff77
let _ScrollUp : keysym = 0x1008ff78
let _ScrollDown : keysym = 0x1008ff79
let _ScrollClick : keysym = 0x1008ff7a
let _Send : keysym = 0x1008ff7b
let _Spell : keysym = 0x1008ff7c
let _SplitScreen : keysym = 0x1008ff7d
let _Support : keysym = 0x1008ff7e
let _TaskPane : keysym = 0x1008ff7f
let _Terminal : keysym = 0x1008ff80
let _Tools : keysym = 0x1008ff81
let _Travel : keysym = 0x1008ff82
let _UserPB : keysym = 0x1008ff84
let _User1KB : keysym = 0x1008ff85
let _User2KB : keysym = 0x1008ff86
let _Video : keysym = 0x1008ff87
let _WheelButton : keysym = 0x1008ff88
let _Word : keysym = 0x1008ff89
let _Xfer : keysym = 0x1008ff8a
let _ZoomIn : keysym = 0x1008ff8b
let _ZoomOut : keysym = 0x1008ff8c
let _Away : keysym = 0x1008ff8d
let _Messenger : keysym = 0x1008ff8e
let _WebCam : keysym = 0x1008ff8f
let _MailForward : keysym = 0x1008ff90
let _Pictures : keysym = 0x1008ff91
let _Music : keysym = 0x1008ff92
let _Battery : keysym = 0x1008ff93
let _Bluetooth : keysym = 0x1008ff94
let _WLAN : keysym = 0x1008ff95
let _UWB : keysym = 0x1008ff96
let _AudioForward : keysym = 0x1008ff97
let _AudioRepeat : keysym = 0x1008ff98
let _AudioRandomPlay : keysym = 0x1008ff99
let _Subtitle : keysym = 0x1008ff9a
let _AudioCycleTrack : keysym = 0x1008ff9b
let _CycleAngle : keysym = 0x1008ff9c
let _FrameBack : keysym = 0x1008ff9d
let _FrameForward : keysym = 0x1008ff9e
let _Time : keysym = 0x1008ff9f
let _SelectButton : keysym = 0x1008ffa0
let _View : keysym = 0x1008ffa1
let _TopMenu : keysym = 0x1008ffa2
let _Red : keysym = 0x1008ffa3
let _Green : keysym = 0x1008ffa4
let _Yellow : keysym = 0x1008ffa5
let _Blue : keysym = 0x1008ffa6
let _Suspend : keysym = 0x1008ffa7
let _Hibernate : keysym = 0x1008ffa8
let _TouchpadToggle : keysym = 0x1008ffa9
let _TouchpadOn : keysym = 0x1008ffb0
let _TouchpadOff : keysym = 0x1008ffb1
let _AudioMicMute : keysym = 0x1008ffb2
let _Switch_VT_1 : keysym = 0x1008fe01
let _Switch_VT_2 : keysym = 0x1008fe02
let _Switch_VT_3 : keysym = 0x1008fe03
let _Switch_VT_4 : keysym = 0x1008fe04
let _Switch_VT_5 : keysym = 0x1008fe05
let _Switch_VT_6 : keysym = 0x1008fe06
let _Switch_VT_7 : keysym = 0x1008fe07
let _Switch_VT_8 : keysym = 0x1008fe08
let _Switch_VT_9 : keysym = 0x1008fe09
let _Switch_VT_10 : keysym = 0x1008fe0a
let _Switch_VT_11 : keysym = 0x1008fe0b
let _Switch_VT_12 : keysym = 0x1008fe0c
let _Ungrab : keysym = 0x1008fe20
let _ClearGrab : keysym = 0x1008fe21
let _Next_VMode : keysym = 0x1008fe22
let _Prev_VMode : keysym = 0x1008fe23
let _LogWindowTree : keysym = 0x1008fe24
let _LogGrabInfo : keysym = 0x1008fe25
